**********************************************************
*******     HH Ent Dynamics 	   ***************************
*******     Data creation do file     ***************************
*******  v11: 2024.01.04        ***************************
**********************************************************

capture log close
log using "HH Ent data $S_DATE.log", replace

***************
*Keep ent. data
***************


***1998 data 
use "elms98_Inddata.dta", clear
keep indid q51021-q5101
save "1998 ent data.dta", replace

***2006 data
use "ELMPS 2006 v4.2.dta"
keep indid q11101_1-q11206_4
save "2006 ent data.dta", replace

***2012 data
use "elmps 2012 xs v2.2 all.dta"
keep indid q13101-q13504_2_304
save "2012 ent data.dta", replace

****2018 data
use "elmps 2018 xs v2.0 all.dta"
keep indid q301 q15*
save "2018 ent data.dta", replace

*****************************
***Economic activity recoding

use "elmps 2018 rep xs 88_18 v2.0.dta", clear

keep if round!=1988 & usecac1d_cl!=.
*139,187 observations deleted

*Make a unique list of occuptaions
duplicates drop round usecactp usecac1d_cl, force
*58,344 observations deleted

keep round usecactp usecac1d_cl

foreach num of numlist 1/4 {
gen ent`num'ecactp=usecactp
gen ent`num'ecac1d=usecac1d_cl
}

drop usecactp usecac1d_cl

save "Ec Ac coding.dta", replace

use "Ec Ac coding.dta", clear
keep round ent1* 
save "Ec Ac 1 coding.dta", replace

use "Ec Ac coding.dta", clear
keep round ent2* 
save "Ec Ac 2 coding.dta", replace

use "Ec Ac coding.dta", clear
keep round ent3* 
save "Ec Ac 3 coding.dta", replace

use "Ec Ac coding.dta", clear
keep round ent4* 
save "Ec Ac 4 coding.dta", replace


*************************Repeated cross section*********************************

use "elmps 2018 rep xs 88_18 v2.0.dta", clear

keep if round!=1988

*Merge in enterprise data
merge 1:1 indid using "1998 ent data.dta"
tabu _merge
drop _merge

merge 1:1 indid using "2006 ent data.dta", update
tabu _merge
drop _merge

merge 1:1 indid using "2012 ent data.dta", update
tabu _merge
drop _merge

merge 1:1 indid using "2018 ent data.dta", update
tabu _merge
drop _merge

*****************
*Enterprise level
*****************

*Economic activity

foreach num of numlist 1/4 {

gen ent`num'ecactp=q5102`num' if round==1998

}

foreach num of numlist 1/4 {

replace ent`num'ecactp=q11102_`num' if round==2006

}

foreach num of numlist 1/4 {

replace ent`num'ecactp=q13104_30`num' if round==2012

}

foreach num of numlist 1/4 {

replace ent`num'ecactp=q15104_`num' if round==2018

}

*Merge coding
merge m:1 round ent1ecactp using "Ec Ac 1 coding.dta", update
tabu _merge
tabu _merge if ent1ecactp!=.
drop if _merge==2
drop _merge

merge m:1 round ent2ecactp using "Ec Ac 2 coding.dta", update
tabu _merge
tabu _merge if ent2ecactp!=.
drop if _merge==2
drop _merge

merge m:1 round ent3ecactp using "Ec Ac 3 coding.dta", update
tabu _merge
tabu _merge if ent3ecactp!=.
drop if _merge==2
drop _merge

merge m:1 round ent4ecactp using "Ec Ac 4 coding.dta", update
tabu _merge
tabu _merge if ent4ecactp!=.
drop if _merge==2
drop _merge


****************************
*Collapsing characteristics
****************************

*Age groups
recode age (0/29=1) (30/49=2) (50/106=3), gen(agegrp3)
la def Lagegrp3 1 "<30" 2 "30-49" 3 "50+"
la val agegrp3 Lagegrp3

*Father's education
recode fteduc (1=1) (2/3=2) (4/5=3) (6/7=4), gen(fteduc2)
la def Lfteduc2 1 "Illiterate" 2 "Less than Intermediate" 3 "Intermediate" 4 "University & Above"
la val fteduc2 Lfteduc2

*Father's employment status
gen ftempst2=1 if ftempst==1 & ftsectr>=1 & ftsectr<=2
replace ftempst2=2 if ftempst==1 & ftsectr>=3 & ftsectr<=8
replace ftempst2=3 if ftempst>=2 & ftempst<=5

la def Lftempst2 1 "Public wage" 2 "Private wage" 3 "Non-wage"
la val ftempst2 Lftempst

*Own education
recode educlvl (2=3) (5=4), gen(educlvl3)

la def Leduclvl3 1 "Illiterate" 3 "Less than Intermediate" 4 "Intermediate" 6 "University & Above", modify
la val educlvl3 Leduclvl3



*LM status

*** Institutional sector definitions

*Self-employed
replace usinstsec=1 if usempstp==3

*Employer
replace usinstsec=3 if usempstp==2

*Unpaid family worker
replace usinstsec=4 if (usempstp==4 | usempstp==5)

*Irregular
replace usinstsec=6 if usempstp==1 & usirreg==1
*Informal private regular
replace usinstsec=7 if usempstp==1 & usformal==0 & ussectrp!=1 & ussectrp!=2 & usirreg==0
*Formal private regular
replace usinstsec=8 if usempstp==1 & usformal==1 & ussectrp!=1 & ussectrp!=2 & usirreg==0
*Public enterprise
replace usinstsec=9 if ussectrp==2
*Government
replace usinstsec=10 if ussectrp==1
replace usinstsec=11 if uswrkst1==2
replace usinstsec=12 if uswrkst1==3 
replace usinstsec=12 if uswrkst1==. & (age<15 | age>64)

la def Lusinstsec 1 "Self-employed" 4 "Unpaid fam. wrk." 11 "Unemployed" 12 "OLF", modify

tabu usinstsec



****************
*Household level
****************

***Household has a non-agricultural enterprise

gen hh_ent=0
replace hh_ent=1 if q5101==1 & round==1998 & ///
((ent1ecac1d!=0 & ent1ecac1d!=.) | (ent2ecac1d!=0 & ent2ecac1d!=.)  | (ent3ecac1d!=0 & ent3ecac1d!=.) | (ent4ecac1d!=0 & ent4ecac1d!=.) )
replace hh_ent=1 if q11101_1==1 & round==2006 & ///
((ent1ecac1d!=0 & ent1ecac1d!=.) | (ent2ecac1d!=0 & ent2ecac1d!=.)  | (ent3ecac1d!=0 & ent3ecac1d!=.) | (ent4ecac1d!=0 & ent4ecac1d!=.) )
replace hh_ent=1 if q13101==1 & round==2012 & ///
((ent1ecac1d!=0 & ent1ecac1d!=.) | (ent2ecac1d!=0 & ent2ecac1d!=.)  | (ent3ecac1d!=0 & ent3ecac1d!=.) | (ent4ecac1d!=0 & ent4ecac1d!=.) )
replace hh_ent=1 if q15101==1 & round==2018 & ///
((ent1ecac1d!=0 & ent1ecac1d!=.) | (ent2ecac1d!=0 & ent2ecac1d!=.)  | (ent3ecac1d!=0 & ent3ecac1d!=.) | (ent4ecac1d!=0 & ent4ecac1d!=.) )

*Head level
replace hh_ent=. if pn!=1

la var hh_ent "Household enterprise"
la def Lhh_ent 0 "No enterprise" 1 "Has enterprise"
la val hh_ent Lhh_ent


****************
*Individual level
****************

***Individual works on an enterprise, rank in enterprise

gen indiv_ent=0
gen indiv_rank=.

foreach num of numlist 1/4 {
gen indiv_ent`num'=0
foreach num2 of numlist 1/6 {
replace indiv_ent`num'=1 if q5104`num2'a`num'==pn & round==1998 & ent`num'ecac1d!=0
replace indiv_rank=`num2' if q5104`num2'a`num'==pn & round==1998 & ent`num'ecac1d!=0 & `num2'<indiv_rank
}
}

foreach num of numlist 1/4 {
foreach num2 of numlist 1/6 {

replace indiv_ent`num'=1 if q11104_`num2'_`num' ==pn & round==2006 & ent`num'ecac1d!=0
replace indiv_rank=`num2' if q11104_`num2'_`num' ==pn & round==2006 & ent`num'ecac1d!=0 & `num2'<indiv_rank
}
}

foreach num of numlist 1/4 {
foreach num2 of numlist 1/6 {
replace indiv_ent`num'=1 if q13105_`num2'_30`num'==pn & round==2012 & ent`num'ecac1d!=0
replace indiv_rank=`num2' if q13105_`num2'_30`num'==pn & round==2012 & ent`num'ecac1d!=0 & `num2'<indiv_rank

}
}

foreach num of numlist 1/4 {
foreach num2 of numlist 1/3 {
replace indiv_ent`num'=1 if q15105_`num2'a_`num'==pn & round==2018 & ent`num'ecac1d!=0
replace indiv_rank=`num2' if q15105_`num2'a_`num'==pn & round==2018 & ent`num'ecac1d!=0 & `num2'<indiv_rank

replace indiv_ent=1 if indiv_ent`num'==1
}
}

tab1 indiv_ent*
tabu indiv_rank

gen indiv_prim=0
replace indiv_prim=1 if indiv_rank==1

gen indiv_sec=0
replace indiv_sec=1 if indiv_rank>=2 & indiv_rank<.

*Losing an adult household member

gen lost_adult_98=0
replace lost_adult_98=1 if in_1998==1 & in_2006==0 & age>=10 & round==1998
egen hh_lost_adult_98=max(lost_adult) if in_1998==1 & round==1998, by(hhid)

gen lost_adult_06=0
replace lost_adult_06=1 if in_2006==1 & in_2012==0 & age>=12 & round==2006
egen hh_lost_adult_06=max(lost_adult_06) if in_2006==1 & round==2006, by(hhid)

gen lost_adult_12=0
replace lost_adult_12=1 if in_2012==1 & in_2018==0 & age>=12 & round==2012
egen hh_lost_adult_12=max(lost_adult_12) if in_2012==1 & round==2012, by(hhid)

gen hh_lost_adult=hh_lost_adult_12 if round==2012
replace hh_lost_adult=hh_lost_adult_06 if round==2006
replace hh_lost_adult=hh_lost_adult_98 if round==1998

*Losing a household member involved in the enterprise

gen ent_lost_adult_98=0
replace ent_lost_adult_98=1 if in_1998==1 & in_2006==0 & age>=10 & round==1998 & indiv_ent==1
egen hh_ent_lost_adult_98=max(ent_lost_adult) if in_1998==1 & round==1998, by(hhid)

gen ent_lost_adult_06=0
replace ent_lost_adult_06=1 if in_2006==1 & in_2012==0 & age>=12 & round==2006 & indiv_ent==1
egen hh_ent_lost_adult_06=max(ent_lost_adult_06) if in_2006==1 & round==2006, by(hhid)

gen ent_lost_adult_12=0
replace ent_lost_adult_12=1 if in_2012==1 & in_2018==0 & age>=12 & round==2012 & indiv_ent==1
egen hh_ent_lost_adult_12=max(ent_lost_adult_12) if in_2012==1 & round==2012, by(hhid)


gen hh_ent_lost_adult=hh_ent_lost_adult_12 if round==2012
replace hh_ent_lost_adult=hh_ent_lost_adult_06 if round==2006
replace hh_ent_lost_adult=hh_ent_lost_adult_98 if round==1998

*Adding a household member

*1998 
gen add_adult_98=0
replace add_adult_98=1 if in_1998==0 & in_2006==1 & age>=18 & round==2006
egen hh_add_adult_98_06=max(add_adult_98) if round==2006, by(hhid)
egen hh_add_adult_98_t=max(hh_add_adult_98_06), by(Findid)
egen hh_add_adult_98=max(hh_add_adult_98_t) if round==1998, by(hhid)

*2006
gen add_adult_06=0
replace add_adult_06=1 if in_2006==0 & in_2012==1 & age>=18 & round==2012
egen hh_add_adult_06_12=max(add_adult_06) if round==2012, by(hhid)
egen hh_add_adult_06_t=max(hh_add_adult_06_12), by(Findid)
egen hh_add_adult_06=max(hh_add_adult_06_t) if round==2006, by(hhid)

*2012
gen add_adult_12=0
replace add_adult_12=1 if in_2012==0 & in_2018==1 & age>=18 & round==2018
egen hh_add_adult_12_18=max(add_adult_12) if round==2018, by(hhid)
egen hh_add_adult_12_t=max(hh_add_adult_12_18), by(Findid)
egen hh_add_adult_12=max(hh_add_adult_12_t) if round==2012, by(hhid)

gen hh_add_adult=hh_add_adult_12 if round==2012
replace hh_add_adult=hh_add_adult_06 if round==2006
replace hh_add_adult=hh_add_adult_98 if round==1998


 
****************
*Enterprise chars
****************

**Accounting books

foreach num of numlist 1/4 {
gen books_`num'=.

replace books_`num'=1 if q5123`num'==1 & round==1998
replace books_`num'=0 if (q5123`num'==2 | q5123`num'==3 ) & round==1998

replace books_`num'=1 if q11118_`num'==1 & round==2006
replace books_`num'=0 if (q11118_`num'==2 | q11118_`num'==3 ) & round==2006

replace books_`num'=1 if q13115_30`num'==1 & round==2012
replace books_`num'=0 if (q13115_30`num'==2 | q13115_30`num'==3 ) & round==2012

replace books_`num'=1 if q15116_`num'==1 & round==2018
replace books_`num'=0 if (q15116_`num'==2 | q15116_`num'==99 ) & round==2018

la val books_`num' yn1

}


**Registration = formality

foreach num of numlist 1/4 {
gen formal_`num'=.

replace formal_`num'=1 if q5122`num'==1 & round==1998
replace formal_`num'=0 if (q5122`num'==2 | q5122`num'==3 ) & round==1998

replace formal_`num'=1 if q11117_`num'==1 & round==2006
replace formal_`num'=0 if (q11117_`num'==2 | q11117_`num'==3 ) & round==2006

replace formal_`num'=1 if q13114_30`num'==1 & round==2012
replace formal_`num'=0 if (q13114_30`num'==2 | q13114_30`num'==3 ) & round==2012

replace formal_`num'=1 if q15115_`num'==1 & round==2018
replace formal_`num'=0 if (q15115_`num'==2 | q15115_`num'==99 ) & round==2018

la val formal_`num' yn1

}


**Ownership

foreach num of numlist 1/4 {
gen partner_`num'=.

replace partner_`num'=0 if q5106a`num'==1 & round==1998
replace partner_`num'=1 if q5106a`num'==2 & round==1998

replace partner_`num'=0 if q11106a_`num'==1 & round==2006
replace partner_`num'=1 if q11106a_`num'==2 & round==2006

replace partner_`num'=0 if q13107_1_30`num'==1 & round==2012
replace partner_`num'=1 if q13107_1_30`num'==2 & round==2012

replace partner_`num'=0 if q15107_`num'==1 & round==2018
replace partner_`num'=1 if q15107_`num'==2 & round==2018

la val partner_`num' yn1

}


**Year of start
**********changed to 1950////2018
la def Lstarty 0 "Don't know" 1 "Before 1950" 2 "1950-1959" 3 "1960-1969" ///
4 "1970-1979" 5 "1980-1989" 6 "1990-1999" 7 "2000-2009" 8 "2010-2018" 

foreach num of numlist 1/4 {
gen starty_`num'=.

replace starty_`num'=q5105a`num' if round==1998
replace starty_`num'=0 if starty_`num'==7 | starty_`num'==-9

replace starty_`num'=q11105_`num' if round==2006
replace starty_`num'=0 if starty_`num'==8 & round==2006

replace starty_`num'=q13106_30`num' if round==2012
replace starty_`num'=0 if starty_`num'==9998 & round==2012

replace starty_`num'=q15106_`num' if round==2018
replace starty_`num'=0 if starty_`num'==9998 & round==2018

replace starty_`num'=1 if starty_`num'>=1900 & starty_`num'<=1949
replace starty_`num'=2 if starty_`num'>=1950 & starty_`num'<=1959
replace starty_`num'=3 if starty_`num'>=1960 & starty_`num'<=1969
replace starty_`num'=4 if starty_`num'>=1970 & starty_`num'<=1979
replace starty_`num'=5 if starty_`num'>=1980 & starty_`num'<=1989
replace starty_`num'=6 if starty_`num'>=1990 & starty_`num'<=1999
replace starty_`num'=7 if starty_`num'>=2000 & starty_`num'<=2009
replace starty_`num'=8 if starty_`num'>=2010 & starty_`num'<=2018

la val starty_`num' Lstarty

}

fre starty_1

**Location

la def Lloc   1 "own home"  2 "shop" 4 "office/flat/building" ///
5 "room/number of rooms" 6 "workshop/factory" 7 "kiosk" 8 "street vendor" ///
9 "mobile worker" 10 "street vendor with mobile cart" 11 "hut" ///
12 "drinks fridge" 14 "basket/table"  15 "van/truck/pick-up truck" ///
16 "taxi" 17 "toc-toc"  18 "field/farm" 97 "other"


foreach num of numlist 1/4 {
gen loc_`num'=.

replace loc_`num'=q5108`num' if round==1998
replace loc_`num'=loc_`num'+1 if loc_`num'>=3
replace loc_`num'=loc_`num'+1 if loc_`num'>=13

replace loc_`num'=q11108_`num' if round==2006
replace loc_`num'=loc_`num'+1 if loc_`num'>=17
replace loc_`num'=17 if loc_`num'==20

replace loc_`num'=q13108_30`num' if round==2012
replace loc_`num'=8 if loc_`num'==20
replace loc_`num'=19 if loc_`num'>=19 & loc_`num'<.
replace loc_`num'=12 if loc_`num'==13
replace loc_`num'=4 if loc_`num'==3

replace loc_`num'=19 if loc_`num'==-9

replace loc_`num'=q15109_`num' if round==2018
replace loc_`num'=4 if loc_`num'==3 & round==2018
replace loc_`num'=4 if loc_`num'==8 & round==2018
replace loc_`num'=4 if loc_`num'==5 & round==2018
replace loc_`num'=5 if loc_`num'==4 & round==2018
replace loc_`num'=15 if loc_`num'==10 & round==2018
replace loc_`num'=16 if loc_`num'==11 & round==2018
replace loc_`num'=17 if loc_`num'==13 & round==2018
replace loc_`num'=18 if loc_`num'==12 & round==2018

replace loc_`num'=97 if loc_`num'==19 
replace loc_`num'=. if loc_`num'==98


la val loc_`num' Lloc
}

la def Lsloc 1 "Own home"  2 "Shop" 3 "Office/flat/building/rooms" ///
4 "Workshop/factory" 5 "Mobile worker" 6 "Street and similar vendors" ///
7 "Transport based"

foreach num of numlist 1/4 {
gen sloc_`num'=.
replace sloc_`num'=loc_`num' if loc_`num'==1 | loc_`num'==2
replace sloc_`num'=3 if loc_`num'==4 | loc_`num'==5
replace sloc_`num'=4 if loc_`num'==6 
replace sloc_`num'=5 if loc_`num'==9 
replace sloc_`num'=6 if loc_`num'==7 | loc_`num'==8  | loc_`num'==10 | loc_`num'==11 ///
| loc_`num'==12 | loc_`num'==14    | loc_`num'==18 | loc_`num'==19           
replace sloc_`num'=7 if loc_`num'==15 | loc_`num'==16 | loc_`num'==17    

la val sloc_`num' Lsloc 
}



*current value of capital

foreach num of numlist 1/4 {
gen kap_`num'=.

replace kap_`num'=q5113`num' if round==1998
replace kap_`num'=kap_`num'-1 if kap_`num'>=2 & kap_`num'<=7

replace kap_`num'=q11110_`num' if round==2006

replace kap_`num'=q13109_30`num' if round==2012

replace kap_`num'=q15110_`num' if round==2018

replace kap_`num'=6 if kap_`num'==7
replace kap_`num'=7 if kap_`num'==8
replace kap_`num'=7 if kap_`num'==-9 | kap_`num'==98


la val kap_`num' capital
}


*Employees from outside the HH

foreach num of numlist 1/4 {
gen empout_`num'=0

replace empout_`num'=1 if q5201`num'==1 & round==1998
replace empout_`num'=0 if q5201`num'==2 & round==1998

replace empout_`num'=1 if q11201_`num'==1 & round==2006
replace empout_`num'=0 if q11201_`num'==2 & round==2006

replace empout_`num'=1 if q13201_30`num'==1 & round==2012
replace empout_`num'=0 if q13201_30`num'==2 & round==2012

replace empout_`num'=1 if q15201_`num'==1 & round==2018
replace empout_`num'=0 if q15201_`num'==2 & round==2018

la val empout_`num' yn1

}



*Number of household members

foreach num of numlist 1/4 {

gen nhhemp_`num'=0

foreach num2 of numlist 1/6 {

replace nhhemp_`num'=nhhemp_`num'+1 if round==1998 & q5104`num2'a`num'!=.

replace nhhemp_`num'=nhhemp_`num'+1 if round==2006 & q11104_`num2'_`num'!=.

replace nhhemp_`num'=nhhemp_`num'+1 if round==2012 & q13105_`num2'_30`num'!=.

}
}
****for 2018, numbering different from previous years
foreach num of numlist 1/4 {

foreach num2 of numlist 1/3 {

replace nhhemp_`num'=nhhemp_`num'+1 if round==2018 & q15105_`num2'a_`num'!=.

replace nhhemp_`num'=0 if nhhemp_`num'<0
}
}


*Number of outside emps (relatives + others)

foreach num of numlist 1/4 {
gen noutemp_`num'=0

*Total minus household
replace noutemp_`num'=noutemp_`num'+q5110_4`num'-nhhemp_`num' if round==1998 & q5110_4`num'!=. & nhhemp_`num'!=. & q5110_4`num'!=-9

*Male plus female minus household
replace noutemp_`num'=noutemp_`num'+q11109m_`num' if round==2006 & q11109m_`num'!=. & q11109m_`num'!=-9
replace noutemp_`num'=noutemp_`num'+q11109f_`num' if round==2006 & q11109f_`num'!=. & q11109f_`num'!=-9
replace noutemp_`num'=noutemp_`num'-nhhemp_`num' if round==2006

*Male outside plus female outside
replace noutemp_`num'=noutemp_`num'+q13202_1_30`num' if round==2012 & q13202_1_30`num'!=. 
replace noutemp_`num'=noutemp_`num'+q13202_2_30`num' if round==2012 & q13202_2_30`num'!=.

*Outside
replace noutemp_`num'=noutemp_`num'+q15202_`num' if round==2018 & q15202_`num'!=.

replace noutemp_`num'=0 if noutemp_`num'<0

}



*Number of total emps

foreach num of numlist 1/4 {
gen ntotemp_`num'=0

replace ntotemp_`num'=noutemp_`num'+nhhemp_`num'

}




*Number of projects

gen numproj=0

foreach num of numlist 1/4 {
replace numproj=numproj+1 if ent`num'ecac1d!=0 & ent`num'ecac1d!=.
}



****Series of questions on employment changes

*New workers joined

foreach num of numlist 1/4 {
gen addwrkyr_`num'=.

replace addwrkyr_`num'=1 if q5202`num'==1 & round==1998
replace addwrkyr_`num'=0 if (q5202`num'==2 | q5202`num'==3) & round==1998

replace addwrkyr_`num'=1 if q11202_`num'==1 & round==2006
replace addwrkyr_`num'=0 if (q11202_`num'==2 | q11202_`num'==3) & round==2006

replace addwrkyr_`num'=1 if q13203_30`num'==1 & round==2012
replace addwrkyr_`num'=0 if (q13203_30`num'==2) & round==2012

replace addwrkyr_`num'=1 if q15203_`num'==1 & round==2018
replace addwrkyr_`num'=0 if (q15203_`num'==2) & round==2018

la val addwrkyr_`num' yn1

}


*Number of new workers joined

foreach num of numlist 1/4 {
gen addwrkyrn_`num'=0

replace addwrkyrn_`num'=q5203`num' if round==1998

replace addwrkyrn_`num'=q11203_`num' if round==2006

replace addwrkyrn_`num'=q13204_30`num' if round==2012

replace addwrkyrn_`num'=q15204_`num' if round==2018

replace addwrkyrn_`num'=. if addwrkyrn_`num'<0

}


*Workers lost

foreach num of numlist 1/4 {
gen losewrkyr_`num'=.

replace losewrkyr_`num'=1 if q5204`num'==1 & round==1998
replace losewrkyr_`num'=0 if (q5204`num'==2 | q5202`num'==3) & round==1998

replace losewrkyr_`num'=1 if q11204_`num'==1 & round==2006
replace losewrkyr_`num'=0 if (q11204_`num'==2 | q11202_`num'==3) & round==2006

replace losewrkyr_`num'=1 if q13205_30`num'==1 & round==2012
replace losewrkyr_`num'=0 if (q13205_30`num'==2) & round==2012

replace losewrkyr_`num'=1 if q15205_`num'==1 & round==2018
replace losewrkyr_`num'=0 if (q15205_`num'==2) & round==2018


la val losewrkyr_`num' yn1

}


*Workers lost number

foreach num of numlist 1/4 {
gen losewrkyrn_`num'=0

replace losewrkyrn_`num'=q5205`num' if round==1998

replace losewrkyrn_`num'=q11205_`num' if round==2006

replace losewrkyrn_`num'=q13206_30`num' if round==2012

replace losewrkyrn_`num'=q15206_`num' if round==2018

replace losewrkyrn_`num'=. if losewrkyrn_`num'<0

}



*Economic activity collapsed

la def Lsecac1d 1 "Manufacturing and related trades" 2 "Construction" 3 "Wholesale and retail" ///
4 "Transportation and storage" 5 "Accommodation and food service" 6 "Various professional acts." ///
7 "Other service" 

foreach num of numlist 1/4 {

gen sent`num'ecac1d=. 
replace sent`num'ecac1d=1 if ent`num'ecac1d==1 | ent`num'ecac1d==2 | ent`num'ecac1d==3  
replace sent`num'ecac1d=2 if ent`num'ecac1d==5
replace sent`num'ecac1d=3 if ent`num'ecac1d==6
replace sent`num'ecac1d=4 if ent`num'ecac1d==7
replace sent`num'ecac1d=5 if ent`num'ecac1d==8
replace sent`num'ecac1d=6 if ent`num'ecac1d>=9 & ent`num'ecac1d<=17
replace sent`num'ecac1d=6 if ent`num'ecac1d==19
replace sent`num'ecac1d=7 if ent`num'ecac1d==18

la val sent`num'ecac1d Lsecac1d

}


********************************************************************************
*Assigning characteristics of primary enterprise to individuals
********************************************************************************

gen iformal=.
gen ipartner=.
gen isloc=.
gen istarty=.
gen ikap=.
gen iempout=.
gen inhhemp=.
gen inoutemp=.
gen isecac1d=.

foreach num of numlist 1/4 {

replace iformal=formal_`num' if indiv_ent`num'==1 & iformal==.

replace ipartner=partner_`num' if indiv_ent`num'==1 & ipartner==.

replace isloc=sloc_`num' if indiv_ent`num'==1 & isloc==.

replace istarty=starty_`num' if indiv_ent`num'==1 & istarty==.

replace ikap=kap_`num' if indiv_ent`num'==1 & ikap==.

replace iempout=empout_`num' if indiv_ent`num'==1 & iempout==.

replace inhhemp=nhhemp_`num' if indiv_ent`num'==1 & inhhemp==.

replace inoutemp=noutemp_`num' if indiv_ent`num'==1 & inoutemp==.

replace isecac1d=sent`num'ecac1d if indiv_ent`num'==1 & isecac1d==.

}

la val iformal yn1

la val ipartner yn1

la val isloc Lsloc

la val istarty Lstarty

la val ikap capital 

la val iempout yn1

la val isecac1d Lsecac1d

************************
*Calculation of employments
************************

egen loswrkyrn=rowtotal(losewrkyrn_1 losewrkyrn_2 losewrkyrn_3 losewrkyrn_4)
egen addwrkyrn=rowtotal(addwrkyrn_1 addwrkyrn_2 addwrkyrn_3 addwrkyrn_4)
egen ntotemp=rowtotal(ntotemp_1 ntotemp_2 ntotemp_3 ntotemp_4)
egen nhhemp=rowtotal(nhhemp_1 nhhemp_2 nhhemp_3 nhhemp_4)
egen noutemp=rowtotal(noutemp_1 noutemp_2 noutemp_3 noutemp_4)

*Expanded
replace ntotemp=ntotemp*expan_hh
replace nhhemp = nhhemp*expan_hh
replace noutemp = noutemp*expan_hh
replace addwrkyrn = addwrkyrn*expan_hh
replace loswrkyrn = loswrkyrn*expan_hh


******************
*Ind and HH data
******************

save "HH ent Ind HH data.dta", replace


************************************
*Ind and HH data - reshape wide
************************************

use "HH ent Ind HH data.dta", clear

keep Findid hh_ent indiv_ent ent*ecac1d round indiv_ent* ///
iformal ipartner isloc istarty ikap iempout inhhemp inoutemp isecac1d ///
formal_1 partner_1 sloc_1 starty_1 kap_1 empout_1 nhhemp_1 noutemp_1 sent1ecac1d wealth ///
hh_lost_adult hh_ent_lost_adult hh_add_adult usinstsec

reshape wide hh_ent indiv_ent ent*ecac1d ///
indiv_ent1 indiv_ent2 indiv_ent3 indiv_ent4 ///
iformal ipartner isloc ///
istarty ikap iempout inhhemp inoutemp isecac1d ///
formal_1 partner_1 sloc_1 starty_1 kap_1 empout_1 nhhemp_1 noutemp_1 sent1ecac1d wealth ///
hh_lost_adult hh_ent_lost_adult hh_add_adult usinstsec, i(Findid) j(round)

rename *1998 *_98 
rename *2006 *_06
rename *2012 *_12
rename *2018 *_18

save "HH ent Ind HH wide.dta", replace



******************
*Enterprise data
******************

use "HH ent Ind HH data.dta", clear

keep indid sent*ecac1d ent*ecactp formal_* ///
partner_* starty* sloc_* kap_* empout_* addwrkyr_* ///
losewrkyr_* indiv_ent* nhhemp_* noutemp_* ntotemp_* ///
expan_hh round Findid indid hhid pn

drop indiv_ent

reshape long sent@ecac1d ent@ecactp formal_@ ///
partner_@ starty_@ sloc_@ kap_@ empout_@ addwrkyr_@ losewrkyr_@ ///
indiv_ent@ nhhemp_@ noutemp_@ ntotemp_@, i(indid) j(ent_num)

keep if sentecac1d!=0 & sentecac1d!=.

tabu sentecac1d round if pn==1 [aw=expan], col nofreq


save "HH ent Ent data.dta", replace


******************
*Enterprise data
******************

*Individual level with multiple enterprises 

use "elmps 2018 panel 98_18 v2.0.dta", clear

gen in_1998=0
replace in_1998=1 if indid_98!=""

gen in_2006=0
replace in_2006=1 if indid_06!=""

gen in_2012=0
replace in_2012=1 if indid_12!=""

gen in_2018=0
replace in_2018=1 if indid_18!=""

merge 1:1 Findid using "HH ent Ind HH wide.dta"

drop _merge

***Matching on enterprise continuing with one or more of previous individuals

**1998

*Was in enterprise, is no longer
gen entsurv1_06=0 if in_1998==1 & in_2006==1 & indiv_ent_98==1 & indiv_ent_06==0

*First enterprise in 1998 match with any in 2006?

gen ent1match_06=.

foreach num of numlist 1/4 {
gen ent`num'_06used=0

replace ent1match_06=`num' if in_1998==1 & in_2006==1 & indiv_ent1_98==1 & indiv_ent`num'_06==1 ///
& ent1ecac1d_98==ent`num'ecac1d_06 & entsurv1_06==.

replace entsurv1_06=1 if in_1998==1 & in_2006==1 & indiv_ent1_98==1 & indiv_ent`num'_06==1 ///
& ent1ecac1d_98==ent`num'ecac1d_06 & entsurv1_06==.

replace ent`num'_06used=1 if in_1998==1 & in_2006==1 & indiv_ent1_98==1 & indiv_ent`num'_06==1 ///
& ent1ecac1d_98==ent`num'ecac1d_06 & ent1match_06==`num'

}

*No matches
replace entsurv1_06=0 if in_1998==1 & in_2006==1 & indiv_ent_98==1 & indiv_ent_06==1 & entsurv1_06==.
replace entsurv1_06=. if ent1ecac1d_98==. | ent1ecac1d_98==0



*Second enterprise in 1998 match with any in 2006?

gen entsurv2_06=0 if in_1998==1 & in_2006==1 & indiv_ent_98==1 & indiv_ent_06==0

gen ent2match_06=.

foreach num of numlist 1/4 {

replace ent2match_06=`num' if in_1998==1 & in_2006==1 & indiv_ent2_98==1 & indiv_ent`num'_06==1 ///
& ent2ecac1d_98==ent`num'ecac1d_06 & entsurv2_06==. & ent1match_06!=`num'

replace entsurv2_06=1 if in_1998==1 & in_2006==1 & indiv_ent2_98==1 & indiv_ent`num'_06==1 ///
& ent2ecac1d_98==ent`num'ecac1d_06 & entsurv2_06==. & ent1match_06!=`num'

replace ent`num'_06used=1 if in_1998==1 & in_2006==1 & indiv_ent2_98==1 & indiv_ent`num'_06==1 ///
& ent2ecac1d_98==ent`num'ecac1d_06 & ent2match_06==`num'

}


*No matches
replace entsurv2_06=0 if in_1998==1 & in_2006==1 & indiv_ent_98==1 & indiv_ent_06==1 & entsurv2_06==.
replace entsurv2_06=. if ent2ecac1d_98==. | ent2ecac1d_98==0



*Third enterprise in 1998 match with any in 2006?

gen entsurv3_06=0 if in_1998==1 & in_2006==1 & indiv_ent_98==1 & indiv_ent_06==0

gen ent3match_06=.

foreach num of numlist 1/4 {

replace ent3match_06=`num' if in_1998==1 & in_2006==1 & indiv_ent3_98==1 & indiv_ent`num'_06==1 ///
& ent3ecac1d_98==ent`num'ecac1d_06 & entsurv3_06==. & ent1match_06!=`num' & ent2match_06!=`num'

replace entsurv3_06=1 if in_1998==1 & in_2006==1 & indiv_ent3_98==1 & indiv_ent`num'_06==1 ///
& ent3ecac1d_98==ent`num'ecac1d_06 & entsurv3_06==. & ent1match_06!=`num' & ent2match_06!=`num'

replace ent`num'_06used=1 if in_1998==1 & in_2006==1 & indiv_ent3_98==1 & indiv_ent`num'_06==1 ///
& ent3ecac1d_98==ent`num'ecac1d_06 & ent3match_06==`num'

}


*No matches
replace entsurv3_06=0 if in_1998==1 & in_2006==1 & indiv_ent_98==1 & indiv_ent_06==1 & entsurv3_06==.
replace entsurv3_06=. if ent3ecac1d_98==. | ent3ecac1d_98==0


*Fourth enterprise in 1998 match with any in 2006?

gen entsurv4_06=0 if in_1998==1 & in_2006==1 & indiv_ent_98==1 & indiv_ent_06==0

gen ent4match_06=.

foreach num of numlist 1/4 {

replace ent4match_06=`num' if in_1998==1 & in_2006==1 & indiv_ent4_98==1 & indiv_ent`num'_06==1 ///
& ent4ecac1d_98==ent`num'ecac1d_06 & entsurv4_06==. & ent1match_06!=`num' & ent2match_06!=`num' & ent3match_06!=`num'

replace entsurv4_06=1 if in_1998==1 & in_2006==1 & indiv_ent4_98==1 & indiv_ent`num'_06==1 ///
& ent4ecac1d_98==ent`num'ecac1d_06 & entsurv4_06==. & ent1match_06!=`num' & ent2match_06!=`num' & ent3match_06!=`num'

replace ent`num'_06used=1 if in_1998==1 & in_2006==1 & indiv_ent4_98==1 & indiv_ent`num'_06==1 ///
& ent4ecac1d_98==ent`num'ecac1d_06 & ent4match_06==`num'

}


*No matches
replace entsurv4_06=0 if in_1998==1 & in_2006==1 & indiv_ent_98==1 & indiv_ent_06==1 & entsurv4_06==.
replace entsurv4_06=. if ent4ecac1d_98==. | ent4ecac1d_98==0


***Household level

foreach num of numlist 1/4 {
egen hhentsurv`num'_06=max(entsurv`num'_06), by(hhid_98)
}



**2006

*Was in enterprise, is no longer
gen entsurv1_12=0 if in_2006==1 & in_2012==1 & indiv_ent_06==1 & indiv_ent_12==0

*First enterprise in 2006 match with any in 2012?

gen ent1match_12=.

foreach num of numlist 1/4 {
gen ent`num'_12used=0

replace ent1match_12=`num' if in_2006==1 & in_2012==1 & indiv_ent1_06==1 & indiv_ent`num'_12==1 ///
& ent1ecac1d_06==ent`num'ecac1d_12 & entsurv1_12==.

replace entsurv1_12=1 if in_2006==1 & in_2012==1 & indiv_ent1_06==1 & indiv_ent`num'_12==1 ///
& ent1ecac1d_06==ent`num'ecac1d_12 & entsurv1_12==.

replace ent`num'_12used=1 if in_2006==1 & in_2012==1 & indiv_ent1_06==1 & indiv_ent`num'_12==1 ///
& ent1ecac1d_06==ent`num'ecac1d_12 & ent1match_12==`num'

}

*No matches
replace entsurv1_12=0 if in_2006==1 & in_2012==1 & indiv_ent_06==1 & indiv_ent_12==1 & entsurv1_12==.
replace entsurv1_12=. if ent1ecac1d_06==. | ent1ecac1d_06==0



*Second enterprise in 2006 match with any in 2012?

gen entsurv2_12=0 if in_2006==1 & in_2012==1 & indiv_ent_06==1 & indiv_ent_12==0

gen ent2match_12=.

foreach num of numlist 1/4 {

replace ent2match_12=`num' if in_2006==1 & in_2012==1 & indiv_ent2_06==1 & indiv_ent`num'_12==1 ///
& ent2ecac1d_06==ent`num'ecac1d_12 & entsurv2_12==. & ent1match_12!=`num'

replace entsurv2_12=1 if in_2006==1 & in_2012==1 & indiv_ent2_06==1 & indiv_ent`num'_12==1 ///
& ent2ecac1d_06==ent`num'ecac1d_12 & entsurv2_12==. & ent1match_12!=`num'

replace ent`num'_12used=1 if in_2006==1 & in_2012==1 & indiv_ent2_06==1 & indiv_ent`num'_12==1 ///
& ent2ecac1d_06==ent`num'ecac1d_12 & ent2match_12==`num'

}


*No matches
replace entsurv2_12=0 if in_2006==1 & in_2012==1 & indiv_ent_06==1 & indiv_ent_12==1 & entsurv2_12==.
replace entsurv2_12=. if ent2ecac1d_06==. | ent2ecac1d_06==0



*Third enterprise in 2006 match with any in 2012?

gen entsurv3_12=0 if in_2006==1 & in_2012==1 & indiv_ent_06==1 & indiv_ent_12==0

gen ent3match_12=.

foreach num of numlist 1/4 {

replace ent3match_12=`num' if in_2006==1 & in_2012==1 & indiv_ent3_06==1 & indiv_ent`num'_12==1 ///
& ent3ecac1d_06==ent`num'ecac1d_12 & entsurv3_12==. & ent1match_12!=`num' & ent2match_12!=`num'

replace entsurv3_12=1 if in_2006==1 & in_2012==1 & indiv_ent3_06==1 & indiv_ent`num'_12==1 ///
& ent3ecac1d_06==ent`num'ecac1d_12 & entsurv3_12==. & ent1match_12!=`num' & ent2match_12!=`num'

replace ent`num'_12used=1 if in_2006==1 & in_2012==1 & indiv_ent3_06==1 & indiv_ent`num'_12==1 ///
& ent3ecac1d_06==ent`num'ecac1d_12 & ent3match_12==`num'

}


*No matches
replace entsurv3_12=0 if in_2006==1 & in_2012==1 & indiv_ent_06==1 & indiv_ent_12==1 & entsurv3_12==.
replace entsurv3_12=. if ent3ecac1d_06==. | ent3ecac1d_06==0


*Fourth enterprise in 2006 match with any in 2012?

gen entsurv4_12=0 if in_2006==1 & in_2012==1 & indiv_ent_06==1 & indiv_ent_12==0

gen ent4match_12=.

foreach num of numlist 1/4 {

replace ent4match_12=`num' if in_2006==1 & in_2012==1 & indiv_ent4_06==1 & indiv_ent`num'_12==1 ///
& ent4ecac1d_06==ent`num'ecac1d_12 & entsurv4_12==. & ent1match_12!=`num' & ent2match_12!=`num' & ent3match_12!=`num'

replace entsurv4_12=1 if in_2006==1 & in_2012==1 & indiv_ent4_06==1 & indiv_ent`num'_12==1 ///
& ent4ecac1d_06==ent`num'ecac1d_12 & entsurv4_12==. & ent1match_12!=`num' & ent2match_12!=`num' & ent3match_12!=`num'

replace ent`num'_12used=1 if in_2006==1 & in_2012==1 & indiv_ent4_06==1 & indiv_ent`num'_12==1 ///
& ent4ecac1d_06==ent`num'ecac1d_12 & ent4match_12==`num'

}


*No matches
replace entsurv4_12=0 if in_2006==1 & in_2012==1 & indiv_ent_06==1 & indiv_ent_12==1 & entsurv4_12==.
replace entsurv4_12=. if ent4ecac1d_06==. | ent4ecac1d_06==0


***Household level

foreach num of numlist 1/4 {
egen hhentsurv`num'_12=max(entsurv`num'_12), by(hhid_06)
}



***2018

*Was in enterprise, is no longer
gen entsurv1_18=0 if in_2012==1 & in_2018==1 & indiv_ent_12==1 & indiv_ent1_18==0

*First enterprise in 2012 match with any in 2018?

gen ent1match_18=.

foreach num of numlist 1/4 {
gen ent`num'_18used=0

replace ent1match_18=`num' if in_2012==1 & in_2018==1 & indiv_ent1_12==1 & indiv_ent`num'_18==1 ///
& ent1ecac1d_12==ent`num'ecac1d_18 & entsurv1_18==.

replace entsurv1_18=1 if in_2012==1 & in_2018==1 & indiv_ent1_12==1 & indiv_ent`num'_18==1 ///
& ent1ecac1d_12==ent`num'ecac1d_18 & entsurv1_18==.

replace ent`num'_18used=1 if in_2012==1 & in_2018==1 & indiv_ent1_12==1 & indiv_ent`num'_18==1 ///
& ent1ecac1d_12==ent`num'ecac1d_18 & ent1match_18==`num'

}

*No matches
replace entsurv1_18=0 if in_2012==1 & in_2018==1 & indiv_ent_12==1 & indiv_ent_18==1 & entsurv1_18==.
replace entsurv1_18=. if ent1ecac1d_12==. | ent1ecac1d_12==0



*Second enterprise in 2012 match with any in 2018?

gen entsurv2_18=0 if in_2012==1 & in_2018==1 & indiv_ent_12==1 & indiv_ent_18==0

gen ent2match_18=.

foreach num of numlist 1/4 {

replace ent2match_18=`num' if in_2012==1 & in_2018==1 & indiv_ent2_12==1 & indiv_ent`num'_18==1 ///
& ent2ecac1d_12==ent`num'ecac1d_18 & entsurv2_18==. & ent1match_18!=`num'

replace entsurv2_18=1 if in_2012==1 & in_2018==1 & indiv_ent2_12==1 & indiv_ent`num'_18==1 ///
& ent2ecac1d_12==ent`num'ecac1d_18 & entsurv2_18==. & ent1match_18!=`num'

replace ent`num'_18used=1 if in_2012==1 & in_2018==1 & indiv_ent2_12==1 & indiv_ent`num'_18==1 ///
& ent2ecac1d_12==ent`num'ecac1d_18 & ent2match_18==`num'

}


*No matches
replace entsurv2_18=0 if in_2012==1 & in_2018==1 & indiv_ent_12==1 & indiv_ent_18==1 & entsurv2_18==.
replace entsurv2_18=. if ent2ecac1d_12==. | ent2ecac1d_12==0



*Third enterprise in 2012 match with any in 2018?

gen entsurv3_18=0 if in_2012==1 & in_2018==1 & indiv_ent_12==1 & indiv_ent_18==0

gen ent3match_18=.

foreach num of numlist 1/4 {

replace ent3match_18=`num' if in_2012==1 & in_2018==1 & indiv_ent3_12==1 & indiv_ent`num'_18==1 ///
& ent3ecac1d_12==ent`num'ecac1d_18 & entsurv3_18==. & ent1match_18!=`num' & ent2match_18!=`num'

replace entsurv3_18=1 if in_2012==1 & in_2018==1 & indiv_ent3_12==1 & indiv_ent`num'_18==1 ///
& ent3ecac1d_12==ent`num'ecac1d_18 & entsurv3_18==. & ent1match_18!=`num' & ent2match_18!=`num'

replace ent`num'_18used=1 if in_2012==1 & in_2018==1 & indiv_ent3_12==1 & indiv_ent`num'_18==1 ///
& ent3ecac1d_12==ent`num'ecac1d_18 & ent3match_18==`num'

}


*No matches
replace entsurv3_18=0 if in_2012==1 & in_2018==1 & indiv_ent_12==1 & indiv_ent_18==1 & entsurv3_18==.
replace entsurv3_18=. if ent3ecac1d_12==. | ent3ecac1d_12==0


*Fourth enterprise in 2012 match with any in 2018?

gen entsurv4_18=0 if in_2012==1 & in_2018==1 & indiv_ent_12==1 & indiv_ent_18==0

gen ent4match_18=.

foreach num of numlist 1/4 {

replace ent4match_18=`num' if in_2012==1 & in_2018==1 & indiv_ent4_12==1 & indiv_ent`num'_18==1 ///
& ent4ecac1d_12==ent`num'ecac1d_18 & entsurv4_18==. & ent1match_18!=`num' & ent2match_18!=`num' & ent3match_18!=`num'

replace entsurv4_18=1 if in_2012==1 & in_2018==1 & indiv_ent4_12==1 & indiv_ent`num'_18==1 ///
& ent4ecac1d_12==ent`num'ecac1d_18 & entsurv4_18==. & ent1match_18!=`num' & ent2match_18!=`num' & ent3match_18!=`num'

replace ent`num'_18used=1 if in_2012==1 & in_2018==1 & indiv_ent4_12==1 & indiv_ent`num'_18==1 ///
& ent4ecac1d_12==ent`num'ecac1d_18 & ent4match_18==`num'

}

*No matches
replace entsurv4_18=0 if in_2012==1 & in_2018==1 & indiv_ent_12==1 & indiv_ent_18==1 & entsurv4_18==.
replace entsurv4_18=. if ent4ecac1d_12==. | ent4ecac1d_12==0

***Household level

foreach num of numlist 1/4 {
egen hhentsurv`num'_18=max(entsurv`num'_18), by(hhid_12)
}


foreach num of numlist 1/4 {
gen hhentexit`num'_06=hhentsurv`num'_06==0 if hhentsurv`num'_06!=.
gen hhentexit`num'_12=hhentsurv`num'_12==0 if hhentsurv`num'_12!=.
gen hhentexit`num'_18=hhentsurv`num'_18==0 if hhentsurv`num'_18!=.
}

***HH Weight is a mean of individual panel weights

egen hh_panel_wt_98_06=mean(panel_wt_98_06), by(hhid_98)
egen hh_panel_wt_06_12=mean(panel_wt_06_12), by(hhid_06)
egen hh_panel_wt_12_18=mean(panel_wt_12_18), by(hhid_12)

rename ent*match* survent*match*
drop ent*used

***Percentage of enterprises created between rounds


**1998

*In both rounds, in enterprise in subsequent
gen ententer1_06=1 if in_1998==1 & in_2006==1 & indiv_ent1_06==1

*First enterprise in 2006 match with any in 1998?

gen ent1match_06=.

foreach num of numlist 1/4 {
gen ent`num'_06used=0

replace ent1match_06=`num' if in_1998==1 & in_2006==1 & indiv_ent1_98==0 & indiv_ent`num'_06==1 ///
& ent1ecac1d_98==ent`num'ecac1d_06 & ententer1_06==.

replace ententer1_06=0 if in_1998==1 & in_2006==1 & indiv_ent1_98==1 & indiv_ent`num'_06==1 ///
& ent1ecac1d_98==ent`num'ecac1d_06 

replace ent`num'_06used=1 if in_1998==1 & in_2006==1 & indiv_ent1_98==1 & indiv_ent`num'_06==1 ///
& ent1ecac1d_98==ent`num'ecac1d_06 & ent1match_06==`num'

}

*No matches
replace ententer1_06=. if ent1ecac1d_06==0



*Second enterprise in 1998 match with any in 2006?

gen ententer2_06=1 if in_1998==1 & in_2006==1 & indiv_ent2_06==1

gen ent2match_06=.

foreach num of numlist 1/4 {

replace ent2match_06=`num' if in_1998==1 & in_2006==1 & indiv_ent2_98==0 & indiv_ent`num'_06==1 ///
& ent2ecac1d_98==ent`num'ecac1d_06 & ententer2_06==. & ent1match_06!=`num'

replace ententer2_06=0 if in_1998==1 & in_2006==1 & indiv_ent2_98==1 & indiv_ent`num'_06==1 ///
& ent2ecac1d_98==ent`num'ecac1d_06 & ententer2_06==. & ent1match_06!=`num'

replace ent`num'_06used=1 if in_1998==1 & in_2006==1 & indiv_ent2_98==1 & indiv_ent`num'_06==1 ///
& ent2ecac1d_98==ent`num'ecac1d_06 & ent2match_06==`num'

}


*No matches
replace ententer2_06=. if ent2ecac1d_98==. | ent2ecac1d_98==0



*Third enterprise in 1998 match with any in 2006?

gen ententer3_06=1 if in_1998==1 & in_2006==1 & indiv_ent3_06==1

gen ent3match_06=.

foreach num of numlist 1/4 {

replace ent3match_06=`num' if in_1998==1 & in_2006==1 & indiv_ent3_98==1 & indiv_ent`num'_06==1 ///
& ent3ecac1d_98==ent`num'ecac1d_06 & ententer3_06==. & ent1match_06!=`num' & ent2match_06!=`num'

replace ententer3_06=0 if in_1998==1 & in_2006==1 & indiv_ent3_98==1 & indiv_ent`num'_06==1 ///
& ent3ecac1d_98==ent`num'ecac1d_06 & ententer3_06==. & ent1match_06!=`num' & ent2match_06!=`num'

replace ent`num'_06used=1 if in_1998==1 & in_2006==1 & indiv_ent3_98==1 & indiv_ent`num'_06==1 ///
& ent3ecac1d_98==ent`num'ecac1d_06 & ent3match_06==`num'

}


*No matches
replace ententer3_06=. if ent3ecac1d_98==0


*Fourth enterprise in 1998 match with any in 2006?

gen ententer4_06=1 if in_1998==1 & in_2006==1 & indiv_ent4_06==1

gen ent4match_06=.

foreach num of numlist 1/4 {

replace ent4match_06=`num' if in_1998==1 & in_2006==1 & indiv_ent4_98==1 & indiv_ent`num'_06==1 ///
& ent4ecac1d_98==ent`num'ecac1d_06 & ententer4_06==. & ent1match_06!=`num' & ent2match_06!=`num' & ent3match_06!=`num'

replace ententer4_06=0 if in_1998==1 & in_2006==1 & indiv_ent4_98==1 & indiv_ent`num'_06==1 ///
& ent4ecac1d_98==ent`num'ecac1d_06 & ententer4_06==. & ent1match_06!=`num' & ent2match_06!=`num' & ent3match_06!=`num'

replace ent`num'_06used=1 if in_1998==1 & in_2006==1 & indiv_ent4_98==1 & indiv_ent`num'_06==1 ///
& ent4ecac1d_98==ent`num'ecac1d_06 & ent4match_06==`num'

}


*No matches
replace ententer4_06=. if ent4ecac1d_98==0


***Household level

foreach num of numlist 1/4 {
egen hhententer`num'_06=min(ententer`num'_06), by(hhid_98)
}




***Percentage of enterprises created between rounds


**2006

*In both rounds, in enterprise in subsequent
gen ententer1_12=1 if in_2006==1 & in_2012==1 & indiv_ent1_12==1

*First enterprise in 2012 match with any in 2006?

gen ent1match_12=.

foreach num of numlist 1/4 {
gen ent`num'_12used=0

replace ent1match_12=`num' if in_2006==1 & in_2012==1 & indiv_ent1_06==0 & indiv_ent`num'_12==1 ///
& ent1ecac1d_06==ent`num'ecac1d_12 & ententer1_12==.

replace ententer1_12=0 if in_2006==1 & in_2012==1 & indiv_ent1_06==1 & indiv_ent`num'_12==1 ///
& ent1ecac1d_06==ent`num'ecac1d_12 

replace ent`num'_12used=1 if in_2006==1 & in_2012==1 & indiv_ent1_06==1 & indiv_ent`num'_12==1 ///
& ent1ecac1d_06==ent`num'ecac1d_12 & ent1match_12==`num'

}

*No matches
replace ententer1_12=. if ent1ecac1d_12==0



*Second enterprise in 2006 match with any in 2012?

gen ententer2_12=1 if in_2006==1 & in_2012==1 & indiv_ent2_12==1

gen ent2match_12=.

foreach num of numlist 1/4 {

replace ent2match_12=`num' if in_2006==1 & in_2012==1 & indiv_ent2_06==0 & indiv_ent`num'_12==1 ///
& ent2ecac1d_06==ent`num'ecac1d_12 & ententer2_12==. & ent1match_12!=`num'

replace ententer2_12=0 if in_2006==1 & in_2012==1 & indiv_ent2_06==1 & indiv_ent`num'_12==1 ///
& ent2ecac1d_06==ent`num'ecac1d_12 & ententer2_12==. & ent1match_12!=`num'

replace ent`num'_12used=1 if in_2006==1 & in_2012==1 & indiv_ent2_06==1 & indiv_ent`num'_12==1 ///
& ent2ecac1d_06==ent`num'ecac1d_12 & ent2match_12==`num'

}


*No matches
replace ententer2_12=. if ent2ecac1d_06==. | ent2ecac1d_06==0



*Third enterprise in 2006 match with any in 2012?

gen ententer3_12=1 if in_2006==1 & in_2012==1 & indiv_ent3_12==1

gen ent3match_12=.

foreach num of numlist 1/4 {

replace ent3match_12=`num' if in_2006==1 & in_2012==1 & indiv_ent3_06==1 & indiv_ent`num'_12==1 ///
& ent3ecac1d_06==ent`num'ecac1d_12 & ententer3_12==. & ent1match_12!=`num' & ent2match_12!=`num'

replace ententer3_12=0 if in_2006==1 & in_2012==1 & indiv_ent3_06==1 & indiv_ent`num'_12==1 ///
& ent3ecac1d_06==ent`num'ecac1d_12 & ententer3_12==. & ent1match_12!=`num' & ent2match_12!=`num'

replace ent`num'_12used=1 if in_2006==1 & in_2012==1 & indiv_ent3_06==1 & indiv_ent`num'_12==1 ///
& ent3ecac1d_06==ent`num'ecac1d_12 & ent3match_12==`num'

}


*No matches
replace ententer3_12=. if ent3ecac1d_06==0


*Fourth enterprise in 2006 match with any in 2012?

gen ententer4_12=1 if in_2006==1 & in_2012==1 & indiv_ent4_12==1

gen ent4match_12=.

foreach num of numlist 1/4 {

replace ent4match_12=`num' if in_2006==1 & in_2012==1 & indiv_ent4_06==1 & indiv_ent`num'_12==1 ///
& ent4ecac1d_06==ent`num'ecac1d_12 & ententer4_12==. & ent1match_12!=`num' & ent2match_12!=`num' & ent3match_12!=`num'

replace ententer4_12=0 if in_2006==1 & in_2012==1 & indiv_ent4_06==1 & indiv_ent`num'_12==1 ///
& ent4ecac1d_06==ent`num'ecac1d_12 & ententer4_12==. & ent1match_12!=`num' & ent2match_12!=`num' & ent3match_12!=`num'

replace ent`num'_12used=1 if in_2006==1 & in_2012==1 & indiv_ent4_06==1 & indiv_ent`num'_12==1 ///
& ent4ecac1d_06==ent`num'ecac1d_12 & ent4match_12==`num'

}


*No matches
replace ententer4_12=. if ent4ecac1d_06==0


***Household level

foreach num of numlist 1/4 {
egen hhententer`num'_12=min(ententer`num'_12), by(hhid_06)
}

***Percentage of enterprises created between rounds

**2012

*In both rounds, in enterprise in subsequent
gen ententer1_18=1 if in_2012==1 & in_2018==1 & indiv_ent1_18==1

*First enterprise in 2018 match with any in 2012?

gen ent1match_18=.

foreach num of numlist 1/4 {
gen ent`num'_18used=0

replace ent1match_18=`num' if in_2012==1 & in_2018==1 & indiv_ent1_12==0 & indiv_ent`num'_18==1 ///
& ent1ecac1d_12==ent`num'ecac1d_18 & ententer1_18==.

replace ententer1_18=0 if in_2012==1 & in_2018==1 & indiv_ent1_12==1 & indiv_ent`num'_18==1 ///
& ent1ecac1d_12==ent`num'ecac1d_18 

replace ent`num'_18used=1 if in_2012==1 & in_2018==1 & indiv_ent1_12==1 & indiv_ent`num'_18==1 ///
& ent1ecac1d_12==ent`num'ecac1d_18 & ent1match_18==`num'

}

*No matches
replace ententer1_18=. if ent1ecac1d_18==0

*Second enterprise in 2012 match with any in 2018?

gen ententer2_18=1 if in_2012==1 & in_2018==1 & indiv_ent2_18==1

gen ent2match_18=.

foreach num of numlist 1/4 {

replace ent2match_18=`num' if in_2012==1 & in_2018==1 & indiv_ent2_12==0 & indiv_ent`num'_18==1 ///
& ent2ecac1d_12==ent`num'ecac1d_18 & ententer2_18==. & ent1match_18!=`num'

replace ententer2_18=0 if in_2012==1 & in_2018==1 & indiv_ent2_12==1 & indiv_ent`num'_18==1 ///
& ent2ecac1d_12==ent`num'ecac1d_18 & ententer2_18==. & ent1match_18!=`num'

replace ent`num'_18used=1 if in_2012==1 & in_2018==1 & indiv_ent2_12==1 & indiv_ent`num'_18==1 ///
& ent2ecac1d_12==ent`num'ecac1d_18 & ent2match_18==`num'

}

*No matches
replace ententer2_18=. if ent2ecac1d_12==. | ent2ecac1d_12==0



*Third enterprise in 2012 match with any in 2018?

gen ententer3_18=1 if in_2012==1 & in_2018==1 & indiv_ent3_18==1

gen ent3match_18=.

foreach num of numlist 1/4 {

replace ent3match_18=`num' if in_2012==1 & in_2018==1 & indiv_ent3_12==1 & indiv_ent`num'_18==1 ///
& ent3ecac1d_12==ent`num'ecac1d_18 & ententer3_18==. & ent1match_18!=`num' & ent2match_18!=`num'

replace ententer3_18=0 if in_2012==1 & in_2018==1 & indiv_ent3_12==1 & indiv_ent`num'_18==1 ///
& ent3ecac1d_12==ent`num'ecac1d_18 & ententer3_18==. & ent1match_18!=`num' & ent2match_18!=`num'

replace ent`num'_18used=1 if in_2012==1 & in_2018==1 & indiv_ent3_12==1 & indiv_ent`num'_18==1 ///
& ent3ecac1d_12==ent`num'ecac1d_18 & ent3match_18==`num'

}


*No matches
replace ententer3_18=. if ent3ecac1d_12==0


*Fourth enterprise in 2012 match with any in 2018?

gen ententer4_18=1 if in_2012==1 & in_2018==1 & indiv_ent4_18==1

gen ent4match_18=.

foreach num of numlist 1/4 {

replace ent4match_18=`num' if in_2012==1 & in_2018==1 & indiv_ent4_12==1 & indiv_ent`num'_18==1 ///
& ent4ecac1d_12==ent`num'ecac1d_18 & ententer4_18==. & ent1match_18!=`num' & ent2match_18!=`num' & ent3match_18!=`num'

replace ententer4_18=0 if in_2012==1 & in_2018==1 & indiv_ent4_12==1 & indiv_ent`num'_18==1 ///
& ent4ecac1d_12==ent`num'ecac1d_18 & ententer4_18==. & ent1match_18!=`num' & ent2match_18!=`num' & ent3match_18!=`num'

replace ent`num'_18used=1 if in_2012==1 & in_2018==1 & indiv_ent4_12==1 & indiv_ent`num'_18==1 ///
& ent4ecac1d_12==ent`num'ecac1d_18 & ent4match_18==`num'

}


*No matches
replace ententer4_18=. if ent4ecac1d_12==0


***Household level

foreach num of numlist 1/4 {
egen hhententer`num'_18=min(ententer`num'_18), by(hhid_12)
}


keep Findid hhid* hhent* hh_panel* surv*ent*match* indiv_ent* ///

save "HH Ent Ent wide.dta", replace


log close
