**********************************************************
*******     HH Ent Dynamics 	   ***************************
*******     Descriptives do file     ***************************
*******  v2: 2024.01.05 CGK        ***************************
**********************************************************

capture log close
log using "HH Ent desc $S_DATE.log", replace
*Previously in data file
set scheme s1mono

use "HH ent Ind HH data.dta", clear

*Figure
table round if pn==1 [aw=expan_hh], c(mean hh_ent)

table round sex if age>=15 & age<=64 [aw=expan_indiv], c(mean indiv_ent)


***Table: Household characteristics: % with enterprises
gen hh_ent_pct=hh_ent*100

tabout agegrp3 sex urban region qwealth round if pn==1 [aw=expan_hh] using hhlev_desc.xls, replace ///
sum c(mean hh_ent_pct) ptotal(single) npos(row) 

*Table: Employment
table round if hh_ent==1, c(sum ntotemp sum nhhemp sum noutemp sum addwrkyrn sum loswrkyrn) format(%10.0f) 

table round if usemp1==1 [pw=expan_ind], format(%10.0f)

*Pattern check
table crinstsec round if cremp2==1 & crecac1d_cl!=0 & crinstsec<=5 [pw=expan_ind], format(%10.0f) row


***Table: Individuals
gen indiv_ent_pct=indiv_ent*100
gen indiv_prim_pct=indiv_prim*100
gen indiv_sec_pct=indiv_sec*100

tabout agegrp3 sex educlvl3 fteduc2 ftempst2 urban region qwealth round if age>=15 & age<=64 [aw=expan_indiv] using indivlev.xls, replace ///
sum c(mean indiv_ent_pct) ptotal(single) npos(row)

tabout agegrp3 sex educlvl3 fteduc2 ftempst2 urban region qwealth round if age>=15 & age<=64 [aw=expan_indiv] using indivlev.xls, append ///
sum c(mean indiv_prim_pct) ptotal(single) npos(row)

tabout agegrp3 sex educlvl3 fteduc2 ftempst2 urban region qwealth round if age>=15 & age<=64 [aw=expan_indiv] using indivlev.xls, append ///
sum c(mean indiv_sec_pct) ptotal(single) npos(row)

***Table: Number of projects
tabu numproj round if hh_ent==1 [aw=expan_hh], col nofreq


*Percentage of wage employees in companies
tabu lgl round if ussectrp>=3 & ussectrp<=5 [aw=expan_indiv], col nofreq
tabu lgl round if usfirm_size<=4 & ussectrp>=3 & ussectrp<=5 [aw=expan_indiv], col nofreq


*Household enterprise level
use "HH ent Ent data.dta", clear

*Table: Economic activities
tabout sentecac1d round if pn==1 [aw=expan] using entecac.xls, replace ///
c(col) ptotal(none) npos(row)

*Table: Characteristics
tabout formal_ partner_ starty_ sloc_ kap_ empout_ ///
addwrkyr_ losewrkyr_ round round if pn==1 [aw=expan_hh] using entchar.xls, replace ///
c(col) ptotal(none) npos(row)

*Figure: Distribution by size 
sum ntotemp_ [aw=expan_hh], detail
tabu ntotemp_ [aw=expan_hh]

*Recoding to 10+
foreach var of varlist ntotemp_ nhhemp_ noutemp_ {
	replace `var'=10 if `var'>10 & `var'<.
}

foreach num of numlist 0/10 {
	foreach var of varlist ntotemp_ nhhemp_ noutemp_ {
		gen `var'`num'=(`var'==`num')*100
	}
}

collapse ntotemp_* nhhemp_* noutemp_* [aw=expan_hh], by(round)

keep ntotemp_* nhhemp_* noutemp_* round
drop ntotemp_ nhhemp_ noutemp_
reshape long ntotemp_ nhhemp_ noutemp_, i(round) j(size)

la def Lsize 10 "10+"
la val size Lsize

graph twoway line ntotemp_ size if round==1998 & size!=0, lcolor(gs13) || line ntotemp_ size if round==2006 & size!=0, lcolor(gs9) lpatt(dash) || line ntotemp_ size if round==2012 & size!=0, lcolor(gs5) lpatt(dash_dot) || line ntotemp_ size if round==2018 & size!=0, lcolor(gs1) plotregion(margin(none)) legend(span row(1) order(1 "1998" 2 "2006" 3 "2012" 4 "2018")) xtitle("Employment") ytitle("Percentage") ylabel(0(20)100) xlabel(0 2 4 6 8 10 "10+") title("Total employment")

graph save "total emp dist.gph", replace
graph export "total emp dist.png", width(1500) replace

graph twoway line nhhemp_ size if round==1998 & size!=0, lcolor(gs13) || line nhhemp_ size if round==2006 & size!=0, lcolor(gs9) lpatt(dash) || line nhhemp_ size if round==2012 & size!=0, lcolor(gs5) lpatt(dash_dot) || line nhhemp_ size if round==2018 & size!=0, lcolor(gs1) plotregion(margin(none)) legend(span row(1) order(1 "1998" 2 "2006" 3 "2012" 4 "2018")) xtitle("Employment") ytitle("Percentage") ylabel(0(20)100) xlabel(0 2 4 6 8 10 "10+") title("Household member employment")

graph save "hh emp dist.gph", replace
graph export "hh emp dist.png", width(1500) replace

graph twoway line noutemp_ size if round==1998, lcolor(gs13) || line noutemp_ size if round==2006, lcolor(gs9) lpatt(dash) || line noutemp_ size if round==2012, lcolor(gs5) lpatt(dash_dot) || line noutemp_ size if round==2018, lcolor(gs1) plotregion(margin(none)) legend(span row(1) order(1 "1998" 2 "2006" 3 "2012" 4 "2018")) xtitle("Employment") ytitle("Percentage") ylabel(0(20)100) xlabel(0 2 4 6 8 10 "10+") title("Outside employment")

graph save "out emp dist.gph", replace
graph export "out emp dist.png", width(1500) replace

grc1leg "hh emp dist.gph" "out emp dist.gph" "total emp dist.gph", col(1)
graph display, xsize(15) ysize(20)

graph save "emp dist.gph", replace
graph export "emp dist.png", width(1500) replace

log close
