**********************************************************
*******     HH Ent Dynamics 	   ***************************
*******     Dynamics do file     ***************************
*******  v12: 2024.01.04        ***************************
**********************************************************

estimates clear

capture log close

log using "HH ent dynamics log $S_DATE.log", replace

use "elmps 2018 panel 98_18 v2.0.dta", clear

gen in_1998=0
replace in_1998=1 if indid_98!=""

gen in_2006=0
replace in_2006=1 if indid_06!=""

gen in_2012=0
replace in_2012=1 if indid_12!=""

gen in_2018=0
replace in_2018=1 if indid_18!=""
drop usinstsec*

label drop Lusinstsec

merge 1:1 Findid using "HH ent Ind HH wide.dta"

drop _merge


***Do individuals enter enterprise work
gen indiv_enterE06=indiv_ent_06==1 if in_1998==1 & in_2006==1 & indiv_ent_98==0
gen indiv_enterE12=indiv_ent_12==1 if in_2006==1 & in_2012==1 & indiv_ent_06==0
gen indiv_enterE18=indiv_ent_18==1 if in_2012==1 & in_2018==1 & indiv_ent_12==0


***Do individuals exit enterprise work
gen indiv_exitE06=indiv_ent_06==0 if in_1998==1 & in_2006==1 & indiv_ent_98==1
gen indiv_exitE12=indiv_ent_12==0 if in_2006==1 & in_2012==1 & indiv_ent_06==1
gen indiv_exitE18=indiv_ent_18==0 if in_2012==1 & in_2018==1 & indiv_ent_12==1

***Do individuals remain in enterprise work in the same economic activity

gen indiv_exitEact06=1 if indiv_exitE06!=.

foreach num of numlist 1/4 {
foreach num2 of numlist 1/4 {
replace indiv_exitEact06=0 if indiv_ent`num'_98==1 & indiv_ent`num'_06==1 & ///
ent`num'ecac1d_98==ent`num2'ecac1d_06 
}
}


gen indiv_exitEact12=1 if indiv_exitE12!=.

foreach num of numlist 1/4 {
foreach num2 of numlist 1/4 {
replace indiv_exitEact12=0 if indiv_ent`num'_06==1 & indiv_ent`num'_12==1 & ///
ent`num'ecac1d_06==ent`num2'ecac1d_12 
}
}

gen indiv_exitEact18=1 if indiv_exitE18!=.

foreach num of numlist 1/4 {
foreach num2 of numlist 1/4 {
replace indiv_exitEact18=0 if indiv_ent`num'_12==1 & indiv_ent`num'_18==1 & ///
ent`num'ecac1d_12==ent`num2'ecac1d_18 
}
}


***Individual dynamics
gen indiv_dynam_06=1 if indiv_exitE06==0 & indiv_exitEact06==0
replace indiv_dynam_06=2 if indiv_exitE06==0 & indiv_exitEact06==1
replace indiv_dynam_06=3 if indiv_exitE06==1 & indiv_exitEact06==1

gen indiv_dynam_12=1 if indiv_exitE12==0 & indiv_exitEact12==0
replace indiv_dynam_12=2 if indiv_exitE12==0 & indiv_exitEact12==1
replace indiv_dynam_12=3 if indiv_exitE12==1 & indiv_exitEact12==1

gen indiv_dynam_18=1 if indiv_exitE18==0 & indiv_exitEact18==0
replace indiv_dynam_18=2 if indiv_exitE18==0 & indiv_exitEact18==1
replace indiv_dynam_18=3 if indiv_exitE18==1 & indiv_exitEact18==1

la def Ldynamics 1 "Persist" 2 "Switch" 3 "Exit"

la val indiv_dynam_06 Ldynamics
la val indiv_dynam_12 Ldynamics
la val indiv_dynam_18 Ldynamics

***HH Weight is a mean of individual panel weights

egen hh_panel_wt_98_06=mean(panel_wt_98_06), by(hhid_98)
egen hh_panel_wt_06_12=mean(panel_wt_06_12), by(hhid_06)
egen hh_panel_wt_12_18=mean(panel_wt_12_18), by(hhid_12)


***Do non-enterprise households start enterprises?
*(Is there a HH Ent among one of the members of the HH in subsequent round
*Among households with no HH Ent). Member may have moved

egen hh_entall_98=max(hh_ent_98), by(hhid_98)
egen hh_entall_06=max(hh_ent_06), by(hhid_06)
egen hh_entall_12=max(hh_ent_12), by(hhid_12)
egen hh_entall_18=max(hh_ent_18), by(hhid_18)


egen hh_enterE06=max(indiv_enterE06), by(hhid_98)
replace hh_enterE06=. if in_1998==0 | in_2006==0 | hh_entall_98==1

egen hh_enterE12=max(indiv_enterE12), by(hhid_06)
replace hh_enterE12=. if in_2006==0 | in_2012==0 | hh_entall_06==1

egen hh_enterE18=max(indiv_enterE18), by(hhid_12)
replace hh_enterE18=. if in_2012==0 | in_2018==0 | hh_entall_12==1


***Do household enterprises cease?

egen hh_exitE06=max(indiv_exitE06), by(hhid_98)
egen hh_exitE12=max(indiv_exitE12), by(hhid_06)
egen hh_exitE18=max(indiv_exitE18), by(hhid_12)

***Do household enterprises (same Ec Act) cease?

egen hh_exitEact06=max(indiv_exitEact06), by(hhid_98)
egen hh_exitEact12=max(indiv_exitEact12), by(hhid_06)
egen hh_exitEact18=max(indiv_exitEact18), by(hhid_12)


***Household dynamics
gen hh_dynam_06=1 if hh_exitE06==0 & hh_exitEact06==0
replace hh_dynam_06=2 if hh_exitE06==0 & hh_exitEact06==1
replace hh_dynam_06=3 if hh_exitE06==1 & hh_exitEact06==1

gen hh_dynam_12=1 if hh_exitE12==0 & hh_exitEact12==0
replace hh_dynam_12=2 if hh_exitE12==0 & hh_exitEact12==1
replace hh_dynam_12=3 if hh_exitE12==1 & hh_exitEact12==1

gen hh_dynam_18=1 if hh_exitE18==0 & hh_exitEact18==0
replace hh_dynam_18=2 if hh_exitE18==0 & hh_exitEact18==1
replace hh_dynam_18=3 if hh_exitE18==1 & hh_exitEact18==1

la val hh_dynam_06 Ldynamics
la val hh_dynam_12 Ldynamics
la val hh_dynam_18 Ldynamics


****************
*Table on I HH (ent. later)
****************

*Individual entry, dynamics 1998-2006
tabu indiv_enterE06  [aw=panel_wt_98_06]
tabu indiv_dynam_06  [aw=panel_wt_98_06]

*Individual entry, dynamics 2006-2012
tabu indiv_enterE12  [aw=panel_wt_06_12]
tabu indiv_dynam_12 [aw=panel_wt_06_12]

*Individual entry, dynamics 2012-2018
tabu indiv_enterE18  [aw=panel_wt_12_18]
tabu indiv_dynam_18 [aw=panel_wt_12_18]

*Individual entry 2006 by household enterprise status in 1998
bysort hh_entall_98: sum indiv_enterE06  [aw=panel_wt_98_06]

*Individual entry 2012 by household enterprise status in 2006
bysort hh_entall_06: sum indiv_enterE12  [aw=panel_wt_06_12]

*Individual entry 2018 by household enterprise status in 2012
bysort hh_entall_12: sum indiv_enterE18  [aw=panel_wt_12_18]

*Household entry, exit, exit from same activity 1998-2006
tabu hh_enterE06  if pn_98==1 [aw=hh_panel_wt_98_06]
tabu hh_dynam_06 if pn_98==1 [aw=hh_panel_wt_98_06]

*Household entry, exit, exit from same activity 2006-2012
tabu hh_enterE12  if pn_06==1 [aw=hh_panel_wt_06_12]
tabu hh_dynam_12 if pn_06==1 [aw=hh_panel_wt_06_12]

*Household entry, exit, exit from same activity 2012-2018
tabu hh_enterE18  if pn_12==1 [aw=hh_panel_wt_12_18]
tabu hh_dynam_18 if pn_12==1 [aw=hh_panel_wt_12_18]

****************************
*Collapsing characteristics
****************************

*Age groups
recode age_98 (0/29=1) (30/49=2) (50/106=3), gen(agegrp3_98)
la def Lagegrp3 1 "<30" 2 "30-49" 3 "50+"
la val agegrp3_98 Lagegrp3

recode age_06 (0/29=1) (30/49=2) (50/106=3), gen(agegrp3_06)
la val agegrp3_06 Lagegrp3

recode age_12 (0/29=1) (30/49=2) (50/106=3), gen(agegrp3_12)
la val agegrp3_12 Lagegrp3

recode age_18 (0/29=1) (30/49=2) (50/106=3), gen(agegrp3_18)
la val agegrp3_18 Lagegrp3

*Father's education
recode fteducst_98 (1=1) (2/3=2) (4/5=3) (6/7=4), gen(fteduc2_98)
la def Lfteduc2 1 "Illiterate" 2 "Less than Intermediate" 3 "Intermediate" 4 "University & Above"
la val fteduc2_98 Lfteduc2

recode fteducst_06 (1=1) (2/3=2) (4/5=3) (6/7=4), gen(fteduc2_06)
la val fteduc2_06 Lfteduc2

recode fteducst_12 (1=1) (2/3=2) (4/5=3) (6/7=4), gen(fteduc2_12)
la val fteduc2_12 Lfteduc2

recode fteducst_18 (1=1) (2/3=2) (4/5=3) (6/7=4), gen(fteduc2_18)
la val fteduc2_18 Lfteduc2

*Father's employment status
gen ftempst2_98=1 if ftempst_98==1 & ftsectr_98>=1 & ftsectr_98<=2
replace ftempst2_98=2 if ftempst_98==1 & ftsectr_98>=3 & ftsectr_98<=8
replace ftempst2_98=3 if ftempst_98>=2 & ftempst_98<=5

la def Lftempst2 1 "Public wage" 2 "Private wage" 3 "Non-wage"
la val ftempst2_98 Lftempst

gen ftempst2_06=1 if ftempst_06==1 & ftsectr_06>=1 & ftsectr_06<=2
replace ftempst2_06=2 if ftempst_06==1 & ftsectr_06>=3 & ftsectr_06<=8
replace ftempst2_06=3 if ftempst_06>=2 & ftempst_06<=5

la val ftempst2_06 Lftempst

gen ftempst2_12=1 if ftempst_12==1 & ftsectr_12>=1 & ftsectr_12<=2
replace ftempst2_12=2 if ftempst_12==1 & ftsectr_12>=3 & ftsectr_12<=8
replace ftempst2_12=3 if ftempst_12>=2 & ftempst_12<=5
la val ftempst2_12 Lftempst

gen ftempst2_18=1 if ftempst_18==1 & ftsectr_18>=1 & ftsectr_18<=2
replace ftempst2_18=2 if ftempst_18==1 & ftsectr_18>=3 & ftsectr_18<=8
replace ftempst2_18=3 if ftempst_18>=2 & ftempst_18<=5
la val ftempst2_18 Lftempst


*Own education
recode educlvl_98 (2=3) (5=4), gen(educlvl3_98)

la def Leduclvl3 1 "Illiterate" 3 "Less than Intermediate" 3 "Intermediate" 4 "University & Above"
la val educlvl3_98 Leduclvl3

recode educlvl_06 (2=3) (5=4), gen(educlvl3_06)
la val educlvl3_06 Leduclvl3

recode educlvl_12 (2=3) (5=4), gen(educlvl3_12)
la val educlvl3_12 Leduclvl3

recode educlvl_18 (2=3) (5=4), gen(educlvl3_18)
la val educlvl3_18 Leduclvl3


*Wealth dynamics
gen wdiff_98_06=wealth_06-wealth_98
egen tempdiff=mean(wdiff_98_06), by(hhid_98)
replace wdiff_98_06=tempdiff if wdiff_98_06==. & in_1998==1
drop tempdiff

sum wdiff_98_06 [aw=panel_wt_98_06]
replace wdiff_98_06=wdiff_98_06/r(sd)

gen wdiff_06_12=wealth_12-wealth_06
egen tempdiff=mean(wdiff_06_12), by(hhid_06)
replace wdiff_06_12=tempdiff if wdiff_06_12==. & in_2006==1
drop tempdiff

sum wdiff_06_12 [aw=panel_wt_06_12]
replace wdiff_06_12=wdiff_06_12/r(sd)

gen wdiff_12_18=wealth_18-wealth_12
egen tempdiff=mean(wdiff_12_18), by(hhid_12)
replace wdiff_12_18=tempdiff if wdiff_12_18==. & in_2012==1
drop tempdiff

sum wdiff_12_18 [aw=panel_wt_12_18]
replace wdiff_12_18=wdiff_12_18/r(sd)

**********************
*Dummies
***********************

foreach var of varlist iformal* ///
isloc* istarty* ikap* iempout* isecac1d* ///
formal* partner* ///
sloc* starty* kap* empout* sent1ecac1d* ///
sex* agegrp3* educlvl3* fteduc2* ftempst* ///
region* qwealth* ///
 {
tabu `var', gen(`var'_)
labnoeq `var'_?
}



****************************
*ENTRY Models on individual level
****************************

*Enter between 1998 and 2006
probit indiv_enterE06 b1.sex_98 b2.agegrp3_98 ///
b1.educlvl3_98 b12.usinstsec_98 b1.fteduc2_98 b1.ftempst2_98 ///
b1.region_98 b1.qwealth_98 wdiff_98_06 ///
i.hh_entall_98 b0.hh_add_adult_98 b0.hh_lost_adult_98 ///
 [pw=panel_wt_98_06]


margins, dydx(*) post

estimates store ienter06


*Enter between 2006 and 2012
probit indiv_enterE12 b1.sex_06 b2.agegrp3_06 ///
b1.educlvl3_06 b12.usinstsec_06 b1.fteduc2_06 b1.ftempst2_06 ///
b1.region_06 b1.qwealth_06  wdiff_06_12 ///
b0.hh_add_adult_06 b0.hh_lost_adult_06 i.hh_entall_06 [pw=panel_wt_06_12]

margins, dydx(*) post

estimates store ienter12



*Enter between 2012 and 2018
probit indiv_enterE18 b1.sex_12 b2.agegrp3_12 ///
b1.educlvl3_12 b12.usinstsec_12 b1.fteduc2_12 b1.ftempst2_12 ///
b1.region_12 b1.qwealth_12  wdiff_12_18 ///
b0.hh_add_adult_12 b0.hh_lost_adult_12 i.hh_entall_12 [pw=panel_wt_12_18]

margins, dydx(*) post

estimates store ienter18


****************************
*Dynamic Models on individual level
****************************

*between 1998 and 2006
mlogit indiv_dynam_06 b1.sex_98 b2.agegrp3_98 ///
b1.educlvl3_98 b1.fteduc2_98 b1.ftempst2_98 ///
b1.region_98 b1.qwealth_98 wdiff_98_06 ///
b0.iformal_98 b0.ipartner_98 ///
b1.isloc_98 b0.istarty_98 ///
b1.ikap_98 b0.iempout_98 ///
b1.isecac1d_98 c.inoutemp_98 c.inhhemp_98 ///
b0.hh_add_adult_98 b0.hh_lost_adult_98 b0.hh_ent_lost_adult_98 ///
 [pw=panel_wt_98_06]
 
estimates store iexit06

margins, dydx(*) post predict(outcome(1))

estimates store iexit06_1

estimates restore iexit06

margins, dydx(*) post predict(outcome(2))

estimates store iexit06_2

estimates restore iexit06

margins, dydx(*) post predict(outcome(3))

estimates store iexit06_3


*between 2006 and 2012
mlogit indiv_dynam_12 b1.sex_06 b2.agegrp3_06 ///
b1.educlvl3_06 b1.fteduc2_06 b1.ftempst2_06 ///
b1.region_06 b1.qwealth_06 wdiff_06_12 ///
b0.iformal_06 b0.ipartner_06 ///
b1.isloc_06 b0.istarty_06 ///
b1.ikap_06 b0.iempout_06 ///
b1.isecac1d_06 c.inoutemp_06 c.inhhemp_06 ///
b0.hh_add_adult_06 b0.hh_lost_adult_06 b0.hh_ent_lost_adult_06 ///
[pw=panel_wt_06_12], base(1)


estimates store iexit12

margins, dydx(*) post predict(outcome(1))

estimates store iexit12_1

estimates restore iexit12

margins, dydx(*) post predict(outcome(2))

estimates store iexit12_2

estimates restore iexit12

margins, dydx(*) post predict(outcome(3))

estimates store iexit12_3


*between 2012 and 2018
mlogit indiv_dynam_18 b1.sex_12 b2.agegrp3_12 ///
b1.educlvl3_12 b1.fteduc2_12 b1.ftempst2_12 ///
b1.region_12 b1.qwealth_12 wdiff_12_18 ///
b0.iformal_12 b0.ipartner_12 ///
b1.isloc_12 b0.istarty_12 ///
b1.ikap_12 b0.iempout_12 ///
b1.isecac1d_12 c.inoutemp_12 c.inhhemp_12 ///
b0.hh_add_adult_12 b0.hh_lost_adult_12 b0.hh_ent_lost_adult_12 ///
[pw=panel_wt_12_18], base(1)


estimates store iexit18

margins, dydx(*) post predict(outcome(1))

estimates store iexit18_1

estimates restore iexit18

margins, dydx(*) post predict(outcome(2))

estimates store iexit18_2

estimates restore iexit18

margins, dydx(*) post predict(outcome(3))

estimates store iexit18_3


esttab ienter06 ienter12 ienter18 iexit06_1 iexit06_2 iexit06_3 iexit12_1 iexit12_2 iexit12_3 iexit18_1 iexit18_2 iexit18_3 using IndivHHEnt.csv, starlevel(* 0.05 ** 0.01 *** 0.001) cells(b(star fmt(%9.3f)) se(par)) ///     
	 stats(N, fmt(%9.0g) label("N (Obs.)" ))  ///
	mlabels( "1998-2006 Enter" "2006-2012 Enter" "2012-2018 Enter"  "1998-2006 Persist" "1998-2006 Switch" "1998-2006 Exit "  ///
	 "2006-2012 Persist" "2006-2012 Switch" "2006-2012 Exit" "2012-2018 Persist" "2012-2018 Switch" "2012-2018 Exit" ) ///
	coeflabel( 2.sex_98 "Female" 1.agegrp3_98 "<30" 2.agegrp3_98 "30-49" 3.agegrp3_98 "50+" /// 
	3.educlvl3_98 "Less than Intermediate" 4.educlvl3_98 "Intermediate" 6.educlvl3_98 "University & above" ///
           1.usinstsec_98 "Self-Employed" ///
           3.usinstsec_98 "Employer" 4.usinstsec_98 "Unpaid Fam. Wrk." 6.usinstsec_98 "Irregular Wage" ///
           7.usinstsec_98 "Informal Private Regular Wage" 8.usinstsec_98 "Formal Private Regular Wage" ///
           9.usinstsec_98 "Public Enterprises" 10.usinstsec_98 "Government" 11.usinstsec_98 "Unemployed" ///
	2.fteduc2_98 "Less than int." 3.fteduc2_98 "Intermediate" ///
	 4.fteduc2_98 "University & above" ///
	2.ftempst2_98 "Private wage worker" 3.ftempst2_98 "Non-wage" ///
	 2.region_98 "Alex. and Suez Canal" 3.region_98 "Urban Lower" 4.region_98 "Urban Upper" ///
	  5.region_98 "Rural Lower" 6.region_98 "Rural Upper" ///
	 2.qwealth_98 "Poorer" 3.qwealth_98 "Middle" 4.qwealth_98 "Richer" 5.qwealth_98 "Richest" ///
	wdiff_98_06 "Change in wealth" 1.iformal_98 "Yes" 1.ipartner_98 "Yes" ///
	 2.isloc_98 "Shop" 3.isloc_98 "Office/flat/building/rooms" ///
	4.isloc_98 "Workshop/factory" 5.isloc_98 "Mobile worker" 6.isloc_98 "Street and similar vendors" ///
	7.isloc_98 "Transport based" ///
	1.istarty_98 "Before 1952" 2.istarty_98 "1952-1959" 3.istarty_98 "1960-1969" ///
	4.istarty_98 "1970-1979" 5.istarty_98 "1980-1989" 6.istarty_98 "1990-1999" ///
	 7.istarty_98 "2000-2009" 8.istarty_98 "2010-2018" ///
	  2.ikap_98 "<LE500" 3.ikap_98 "LE500-999" 4.ikap_98 "LE1000-4999" 5.ikap_98 "LE5000-9999" 6.ikap_98 "LE 10000+" 7.ikap_98 "D.K." ///
	 2.isecac1d_98 "Construction" 3.isecac1d_98 "Wholesale and retail" ///
	4.isecac1d_98 "Transportation and storage" 5.isecac1d_98 "Accommodation and food service" ///
	6.isecac1d_98 "Various professional acts." 7.isecac1d_98 "Other service" ///
	inoutemp_98 "Number of outside employees" inhhemp_98 "Number of household employees" ///
	1.hh_entall_98 "Yes" 1.hh_lost_adult_98 "Yes" 1.hh_ent_lost_adult_98 "Yes" 1.hh_add_adult_98 "Yes" ) ///
	refcat(2.sex_98 "Sex (male omit.)" 2.agegrp3_98 "Age group (20-24 omit.)" ///
	3.educlvl3_98 "Education (illit. omit.)" 1.usinstsec_98 "Employment status (OLF omit.)" 2.fteduc2_98 "Father's educ. (illit. omit)" ///
	2.ftempst2_98 "Father's work status (public wage omit.)" 2.region_98 "Region (Greater Cairo omit.)" ///
	2.qwealth_98 "Wealth quintile (Poorest omit.)" 1.iformal_98 "Ent. formal" ///
	1.ipartner_98 "Owned in partnership" ///
	2.isloc_98 "Location (own home omit.)" 1.istarty_98 "Start year (don't know omit.)" ///
	 2.ikap_98 "Capital of enterprise (none omit.)" 1.iempout_98 "Use outside emp." ///
	 2.isecac1d_98 "Economic activity (manuf. omit)" 1.hh_entall_98 "Household had an enterprise" ///
	 1.hh_lost_adult_98 "Household lost an adult" 1.hh_ent_lost_adult_98 "Household ent. lost an adult" ///
	 1.hh_add_adult_98 "Household added an adult" ///
	 2.sex_06 "Sex (male omit.)" 2.agegrp3_06 "Age group (20-24 omit.)" ///
	3.educlvl3_06 "Education (illit. omit.)" 1.usinstsec_06 "Employment status (OLF omit.)" 2.fteduc2_06 "Father's educ. (illit. omit)" ///
	2.ftempst2_06 "Father's work status (public wage omit.)" 2.region_06 "Region (Greater Cairo omit.)" ///
	2.qwealth_06 "Wealth quintile (Poorest omit.)" 1.iformal_06 "Ent. formal" ///
	1.ipartner_06 "Owned in partnership" ///
	2.isloc_06 "Location (own home omit.)" 1.istarty_06 "Start year (don't know omit.)" ///
	 2.ikap_06 "Capital of enterprise (none omit.)" 1.iempout_06 "Use outside emp." ///
	 2.isecac1d_06 "Economic activity (manuf. omit)" 1.hh_entall_06 "Household had an enterprise" ///
	 1.hh_lost_adult_06 "Household lost an adult" 1.hh_ent_lost_adult_06 "Household ent. lost an adult" ///
	 1.hh_add_adult_06 "Household added an adult" ///
	2.sex_12 "Sex (male omit.)" 2.agegrp3_12 "Age group (20-24 omit.)" ///
	3.educlvl3_12 "Education (illit. omit.)" 1.usinstsec_12 "Employment status (OLF omit.)" 2.fteduc2_12 "Father's educ. (illit. omit)" ///
	2.ftempst2_12 "Father's work status (public wage omit.)" 2.region_12 "Region (Greater Cairo omit.)" ///
	2.qwealth_12 "Wealth quintile (Poorest omit.)" 1.iformal_12 "Ent. formal" ///
	1.ipartner_12 "Owned in partnership" ///
	2.isloc_12 "Location (own home omit.)" 1.istarty_12 "Start year (don't know omit.)" ///
	 2.ikap_12 "Capital of enterprise (none omit.)" 1.iempout_12 "Use outside emp." ///
	 2.isecac1d_12 "Economic activity (manuf. omit)" 1.hh_entall_12 "Household had an enterprise" ///
	 1.hh_lost_adult_12 "Household lost an adult" 1.hh_ent_lost_adult_12 "Household ent. lost an adult" ///
	 1.hh_add_adult_12 "Household added an adult" , label("") ) ///
	nobase ///
	varwidth(12) modelwidth(8) replace



****************************
*ENTRY Models on household level
****************************

*Enter between 1998 and 2006
probit hh_enterE06 b1.sex_98 b2.agegrp3_98 ///
b1.educlvl3_98 b12.usinstsec_98 b1.fteduc2_98 b1.ftempst2_98 ///
b1.region_98 b1.qwealth_98 wdiff_98_06 b0.hh_add_adult_98 b0.hh_lost_adult_98 ///
 if pn_98==1 [pw=hh_panel_wt_98_06]

margins, dydx(*) post

estimates store hhenter06


*Enter between 2006 and 2012
probit hh_enterE12 b1.sex_06 b2.agegrp3_06 ///
b1.educlvl3_06 b12.usinstsec_06 b1.fteduc2_06 b1.ftempst2_06 ///
b1.region_06 b1.qwealth_06 wdiff_06_12 b0.hh_add_adult_06 b0.hh_lost_adult_06 ///
  if pn_06==1 [pw=hh_panel_wt_06_12]

margins, dydx(*) post

estimates store hhenter12


*Enter between 2012 and 2018
probit hh_enterE18 b1.sex_12 b2.agegrp3_12 ///
b1.educlvl3_12 b12.usinstsec_12 b1.fteduc2_12 b1.ftempst2_12 ///
b1.region_12 b1.qwealth_12 wdiff_12_18 b0.hh_add_adult_12 b0.hh_lost_adult_12 ///
  if pn_12==1 [pw=hh_panel_wt_12_18]

margins, dydx(*) post

estimates store hhenter18


****************************
*Dynamic Models on household level
****************************

*Between 1998 and 2006
mlogit hh_dynam_06 b1.sex_98 b2.agegrp3_98 ///
b1.educlvl3_98 b1.fteduc2_98 b1.ftempst2_98 ///
b1.region_98 b1.qwealth_98 wdiff_98_06 ///
b0.formal_1_98 b0.partner_1_98 ///
b1.sloc_1_98 b5.starty_1_98 ///
b1.kap_1_98 b0.empout_1_98  c.noutemp_1_98 c.nhhemp_1_98 ///
b1.sent1ecac1d_98 ///
b0.hh_add_adult_98 b0.hh_lost_adult_98 b0.hh_ent_lost_adult_98 ///
if pn_98==1 [pw=hh_panel_wt_98_06], base(1)

estimates store hhexit06

margins, dydx(*) post predict(outcome(1))

estimates store hhexit06_1

estimates restore hhexit06

margins, dydx(*) post predict(outcome(2))

estimates store hhexit06_2

estimates restore hhexit06

margins, dydx(*) post predict(outcome(3))

estimates store hhexit06_3

*Between 2006 and 2012
mlogit hh_dynam_12 b1.sex_06 b2.agegrp3_06 ///
b1.educlvl3_06 b1.fteduc2_06 b1.ftempst2_06 ///
b1.region_06 b1.qwealth_06 wdiff_06_12 ///
b0.formal_1_06 b0.partner_1_06 ///
b1.sloc_1_06 b5.starty_1_06 ///
b1.kap_1_06 b0.empout_1_06 c.noutemp_1_06 c.nhhemp_1_06 ///
b1.sent1ecac1d_06 ///
b0.hh_add_adult_06 b0.hh_lost_adult_06 b0.hh_ent_lost_adult_06 ///
if pn_06==1 [pw=hh_panel_wt_06_12], base(1)

estimates store hhexit12


margins, dydx(*) post predict(outcome(1))

estimates store hhexit12_1

estimates restore hhexit12

margins, dydx(*) post predict(outcome(2))

estimates store hhexit12_2

estimates restore hhexit12

margins, dydx(*) post predict(outcome(3))

estimates store hhexit12_3


*Between 2012 and 2018
mlogit hh_dynam_18 b1.sex_12 b2.agegrp3_12 ///
b1.educlvl3_12 b1.fteduc2_12 b1.ftempst2_12 ///
b1.region_12 b1.qwealth_12 wdiff_12_18 ///
b0.formal_1_12 b0.partner_1_12 ///
b1.sloc_1_12 b5.starty_1_12 ///
b1.kap_1_12 b0.empout_1_12 c.noutemp_1_12 c.nhhemp_1_12 ///
b1.sent1ecac1d_12 ///
b0.hh_add_adult_12 b0.hh_lost_adult_12 b0.hh_ent_lost_adult_12 ///
if pn_12==1 [pw=hh_panel_wt_12_18], base(1)

estimates store hhexit18


margins, dydx(*) post predict(outcome(1))

estimates store hhexit18_1

estimates restore hhexit18

margins, dydx(*) post predict(outcome(2))

estimates store hhexit18_2

estimates restore hhexit18

margins, dydx(*) post predict(outcome(3))

estimates store hhexit18_3


esttab hhenter06 hhenter12 hhenter18 hhexit06_1 hhexit06_2 hhexit06_3 hhexit12_1 hhexit12_2 hhexit12_3 hhexit18_1 hhexit18_2 hhexit18_3 using HH_HHEnt.csv, starlevel(* 0.05 ** 0.01 *** 0.001) cells(b(star fmt(%9.3f)) se(par)) ///     
	 stats(N, fmt(%9.0g) label("N (Obs.)" ))  ///
	mlabels( "1998-2006 Enter" "2006-2012 Enter" "2012-2018 Enter" "1998-2006 Exit All" "2006-2012 Exit All" "2012-2018 Exit All"  ///
	"1998-2006 Exit Act." "2006-2012 Exit Act." "2012-2018 Exit Act.") ///
coeflabel( 2.sex_98 "Female" 1.agegrp3_98 "<30" 2.agegrp3_98 "30-49" 3.agegrp3_98 "50+" /// 
	3.educlvl3_98 "Less than Intermediate" 4.educlvl3_98 "Intermediate" 6.educlvl3_98 "University & above" ///
           1.usinstsec_98 "Self-Employed" ///
           3.usinstsec_98 "Employer" 4.usinstsec_98 "Unpaid Fam. Wrk." 6.usinstsec_98 "Irregular Wage" ///
           7.usinstsec_98 "Informal Private Regular Wage" 8.usinstsec_98 "Formal Private Regular Wage" ///
           9.usinstsec_98 "Public Enterprises" 10.usinstsec_98 "Government" 11.usinstsec_98 "Unemployed" ///
	2.fteduc2_98 "Less than int." 3.fteduc2_98 "Intermediate" ///
	 4.fteduc2_98 "University & above" ///
	2.ftempst2_98 "Private wage worker" 3.ftempst2_98 "Non-wage" ///
	 2.region_98 "Alex. and Suez Canal" 3.region_98 "Urban Lower" 4.region_98 "Urban Upper" ///
	  5.region_98 "Rural Lower" 6.region_98 "Rural Upper" ///
	 2.qwealth_98 "Poorer" 3.qwealth_98 "Middle" 4.qwealth_98 "Richer" 5.qwealth_98 "Richest" ///
	wdiff_98_06 "Change in wealth" 1.formal_1_98 "Yes" 1.partner_1_98 "Yes" ///
	 2.sloc_1_98 "Shop" 3.sloc_1_98 "Office/flat/building/rooms" ///
	4.sloc_1_98 "Workshop/factory" 5.sloc_1_98 "Mobile worker" 6.sloc_1_98 "Street and similar vendors" ///
	7.sloc_1_98 "Transport based" ///
	0.starty_1_98 "Don't know'" 1.starty_1_98 "Before 1952" 2.starty_1_98 "1952-1959" 3.starty_1_98 "1960-1969" ///
	4.starty_1_98 "1970-1979" 6.starty_1_98 "1990-1999" ///
	 7.starty_1_98 "2000-2009" 8.starty_1_98 "2010-2018" ///
	  2.kap_1_98 "<LE500" 3.kap_1_98 "LE500-999" 4.kap_1_98 "LE1000-4999" 5.kap_1_98 "LE5000-9999" 6.kap_1_98 "LE 10000+" 7.kap_1_98 "D.K." ///
	 2.sent1ecac1d_98 "Construction" 3.sent1ecac1d_98 "Wholesale and retail" ///
	4.sent1ecac1d_98 "Transportation and storage" 5.sent1ecac1d_98 "Accommodation and food service" ///
	6.sent1ecac1d_98 "Various professional acts." 7.sent1ecac1d_98 "Other service" ///
	1.empout_1_98 "Yes" noutemp_1_98 "Number of outside employees" nhhemp_1_98 "Number of household employees" ///
	1.hh_entall_98 "Yes" 1.hh_lost_adult_98 "Yes" 1.hh_ent_lost_adult_98 "Yes" 1.hh_add_adult_98 "Yes" ) ///
	refcat(2.sex_98 "Sex (male omit.)" 1.agegrp3_98 "Age group (30-49 omit.)" ///
	3.educlvl3_98 "Education (illit. omit.)" 1.usinstsec_98 "Employment status (OLF omit.)" 2.fteduc2_98 "Father's educ. (illit. omit)" ///
	2.ftempst2_98 "Father's work status (public wage omit.)" 2.region_98 "Region (Greater Cairo omit.)" ///
	2.qwealth_98 "Wealth quintile (Poorest omit.)" 1.formal_1_98 "Ent. formal" ///
	1.partner_1_98 "Owned in partnership" ///
	2.sloc_1_98 "Location (own home omit.)" 0.starty_1_98 "Start year (1980-1989 omit.)" ///
	 2.kap_1_98 "Capital of enterprise (none omit.)" 1.empout_1_98 "Use outside emp." ///
	 2.sent1ecac1d_98 "Economic activity (manuf. omit)" 1.hh_entall_98 "Household had an enterprise" ///
	 1.hh_lost_adult_98 "Household lost an adult" 1.hh_ent_lost_adult_98 "Household ent. lost an adult" ///
	 1.hh_add_adult_98 "Household added an adult" ///
	 2.sex_06 "Sex (male omit.)" 1.agegrp3_06 "Age group (30-49 omit.)" ///
	3.educlvl3_06 "Education (illit. omit.)" 1.usinstsec_06 "Employment status (OLF omit.)" 2.fteduc2_06 "Father's educ. (illit. omit)" ///
	2.ftempst2_06 "Father's work status (public wage omit.)" 2.region_06 "Region (Greater Cairo omit.)" ///
	2.qwealth_06 "Wealth quintile (Poorest omit.)" 1.formal_1_06 "Ent. formal" ///
	1.partner_1_06 "Owned in partnership" ///
	2.sloc_1_06 "Location (own home omit.)" 0.starty_1_06 "Start year (1980-1989 omit.)" ///
	 2.kap_1_06 "Capital of enterprise (none omit.)" 1.empout_1_06 "Use outside emp." ///
	 2.sent1ecac1d_06 "Economic activity (manuf. omit)" 1.hh_entall_06 "Household had an enterprise" ///
	 1.hh_lost_adult_06 "Household lost an adult" 1.hh_ent_lost_adult_06 "Household ent. lost an adult" ///
	 1.hh_add_adult_06 "Household added an adult" ///
	 	 2.sex_12 "Sex (male omit.)" 1.agegrp3_12 "Age group (30-49 omit.)" ///
	3.educlvl3_12 "Education (illit. omit.)" 1.usinstsec_12 "Employment status (OLF omit.)" 2.fteduc2_12 "Father's educ. (illit. omit)" ///
	2.ftempst2_12 "Father's work status (public wage omit.)" 2.region_12 "Region (Greater Cairo omit.)" ///
	2.qwealth_12 "Wealth quintile (Poorest omit.)" 1.formal_1_12 "Ent. formal" ///
	1.partner_1_12 "Owned in partnership" ///
	2.sloc_1_12 "Location (own home omit.)" 0.starty_1_12 "Start year (1980-1989 omit.)" ///
	 2.kap_1_12 "Capital of enterprise (none omit.)" 1.empout_1_12 "Use outside emp." ///
	 2.sent1ecac1d_12 "Economic activity (manuf. omit)" 1.hh_entall_12 "Household had an enterprise" ///
	 1.hh_lost_adult_12 "Household lost an adult" 1.hh_ent_lost_adult_12 "Household ent. lost an adult" ///
	 1.hh_add_adult_12 "Household added an adult" ) ///
	nobase ///
	varwidth(12) modelwidth(8) replace







*******Enterprise shaped--1998

use "HH Ent Ent wide.dta", clear

gen round=1998

merge 1:1 Findid round using "HH ent Ind HH data.dta"

drop if _merge!=3

keep Findid hhid_98 hhentexit*_06 hhententer*_06 hh_panel* ///
sent*ecac1d ///
formal_* partner_* sloc_* starty_* kap_* ///
empout_* nhhemp_* noutemp_*  ///
sex agegrp3 ///
educlvl3 fteduc2 ftempst2 ///
region qwealth ///
pn

keep if pn==1

reshape long hhentexit@_06 hhententer@_06 ///
sent@ecac1d ///
formal_@ partner_@ sloc_@ starty_@ kap_@ ///
empout_@ nhhemp_@ noutemp_@, i(Findid) j(ent_num) 

*Table (partial)
tabu hhentexit_06 [aw=hh_panel_wt_98_06]

tabu hhententer_06 [aw=hh_panel_wt_98_06]





*Exit activity between 1998 and 2006
probit hhentexit_06 b1.sex b2.agegrp3 ///
b1.educlvl3 b1.fteduc2 b1.ftempst2 ///
b1.region b1.qwealth  ///
b0.formal_ b0.partner_ ///
b1.sloc_ b5.starty_ ///
b1.kap_ b0.empout_ ///
b1.sentecac1d ///
if pn==1 [pw=hh_panel_wt_98_06]

margins, dydx(*) post

estimates store ent06



*******Enterprise shaped--2006

use "HH Ent Ent wide.dta", clear

gen round=2006

merge 1:1 Findid round using "HH ent Ind HH data.dta"

drop if _merge!=3

keep Findid  hhentexit*_12 hhententer*_12 hh_panel* ///
sent*ecac1d ///
formal_* partner_* sloc_* starty_* kap_* ///
empout_* nhhemp_* noutemp_*  ///
sex agegrp3 ///
educlvl3 fteduc2 ftempst2 ///
region qwealth ///
pn

keep if pn==1

reshape long hhentexit@_12 hhententer@_12 ///
sent@ecac1d ///
formal_@ partner_@ sloc_@ starty_@ kap_@ ///
empout_@ nhhemp_@ noutemp_@, i(Findid) j(ent_num) 

*Table (partial)
tabu hhentexit_12 [aw=hh_panel_wt_06_12]

tabu hhententer_12 [aw=hh_panel_wt_06_12]





*Exit activity between 2006 and 2012
probit hhentexit_12 b1.sex b2.agegrp3 ///
b1.educlvl3 b1.fteduc2 b1.ftempst2 ///
b1.region b1.qwealth ///
b0.formal_ b0.partner_ ///
b1.sloc_ b5.starty_ ///
b1.kap_ b0.empout_ ///
b1.sentecac1d ///
if pn==1 [pw=hh_panel_wt_06_12]

margins, dydx(*) post

estimates store ent12


*******Enterprise shaped--2012

use "HH Ent Ent wide.dta", clear

gen round=2012

merge 1:1 Findid round using "HH ent Ind HH data.dta"

drop if _merge!=3

keep Findid  hhentexit*_18 hhententer*_18 hh_panel* ///
sent*ecac1d ///
formal_* partner_* sloc_* starty_* kap_* ///
empout_* nhhemp_* noutemp_*  ///
sex agegrp3 ///
educlvl3 fteduc2 ftempst2 ///
region qwealth ///
pn

keep if pn==1

reshape long hhentexit@_18 hhententer@_18 ///
sent@ecac1d ///
formal_@ partner_@ sloc_@ starty_@ kap_@ ///
empout_@ nhhemp_@ noutemp_@, i(Findid) j(ent_num) 

*Table (partial)
tabu hhentexit_18 [aw=hh_panel_wt_12_18]

tabu hhententer_18 [aw=hh_panel_wt_12_18]

*Exit activity between 2012 and 2018
probit hhentexit_18 b1.sex b2.agegrp3 ///
b1.educlvl3 b1.fteduc2 b1.ftempst2 ///
b1.region b1.qwealth ///
b0.formal_ b0.partner_ ///
b1.sloc_ b5.starty_ ///
b1.kap_ b0.empout_ ///
b1.sentecac1d ///
if pn==1 [pw=hh_panel_wt_12_18]

margins, dydx(*) post

estimates store ent18


esttab ent06 ent12 ent18 using Ent_HHEnt.csv, starlevel(* 0.05 ** 0.01 *** 0.001) cells(b(star fmt(%9.3f)) se(par)) ///     
	 stats(N, fmt(%9.0g) label( "N (Obs.)" ))  ///
	mlabels( 	"1998-2006 Close" "2006-2012 Close" "2012-2018 Close") ///
	coeflabel( 2.sex "Female" 1.agegrp3 "<30" 3.agegrp3 "50+" ///
	3.educlvl3 "Less than Int." 4.educlvl3 "Intermediate" ///
	6.educlvl3 "Univ. and above" ///
	2.fteduc2 "Less than Int." 3.fteduc2 "Intermediate" 4.fteduc2 "University & above" ///
	2.ftempst2 "Private wage" 3.ftempst2 "Non-wage" ///
	 2.region "Alex. and Suez Canal" 3.region "Urban Lower" 4.region "Urban Upper" ///
	  5.region "Rural Lower" 6.region "Rural Upper" ///
	 2.qwealth "Poorer" 3.qwealth "Middle" 4.qwealth "Richer" 5.qwealth "Richest" ///
	 1.formal_ "Yes"  1.partner_ "Yes" ///
	 2.sloc_ "Shop" 3.sloc_ "Office/flat/building/rooms" ///
	4.sloc_ "Workshop/factory" 5.sloc_ "Mobile worker" 6.sloc_ "Street and similar vendors" ///
	7.sloc_ "Transport based" ///
	0.starty_ "Don't know" 1.starty_ "Before 1952" 2.starty_ "1952-1959" 3.starty_ "1960-1969" ///
	4.starty_ "1970-1979"  6.starty_ "1990-1999" ///
	 7.starty_ "2000-2009" 8.starty_ "2010-2018" ///
	 2.kap_ "<LE500" 3.kap_ "LE500-999" 4.kap_ "LE1000-4999" 5.kap_ "LE5000-9999" 6.kap_ "LE 10000+" 7.kap_ "D.K." ///
	 2.sentecac1d "Construction" 3.sentecac1d "Wholesale and retail" ///
	4.sentecac1d "Transportation and storage" 5.sentecac1d "Accommodation and food service" ///
	6.sentecac1d "Various professional acts." 7.sentecac1d "Other service" ///
	noutemp_ "Number of outside employees" nhhemp_ "Number of household employees" 1.empout_ "Yes") ///
	refcat(2.sex "Sex (male omit.)" 2.agegrp3 "Age group (30-49 omit.)" ///
	3.educlvl3 "Education (illit. omit.)" 2.fteduc2 "Father's educ. (illit. omit)" ///
	2.ftempst2 "Father's work status (public wage omit.)" 2.region "Region (Greater Cairo omit.)" ///
	2.qwealth "Wealth quintile (Poorest omit.)" 1.formal_ "Ent. formal" ///
	 1.partner_ "Owned in partnership" ///
	2.sloc_ "Location (own home omit.)" 0.starty_ "Start year (1980-1989 omit.)" ///
	 2.kap_ "Capital of enterprise (none omit.)" 1.empout_ "Use outside emp." ///
	 2.sentecac1d "Economic activity (manuf. omit)"  ///
	) order (*sex *agegrp3 *educlvl3 *fteduc2 *ftempst2 *region *qwealth *formal_ *partner_ *sloc_ *starty_ *kap_ *empout_ *sentecac1d ///
	) ///
	nobase ///
	varwidth(12) modelwidth(8) replace






***********************
*Enterprise employment growth
*************************



*******Enterprise shaped--1998

use "HH Ent Ent wide.dta", clear

gen round=1998

merge 1:1 Findid round using "HH ent Ind HH data.dta"

drop if _merge!=3

***Keeping the folks who stayed and stayed in enterprises

keep if in_1998==1 & in_2006==1 

keep if survent1match_06!=. | survent2match_06!=. | survent3match_06!=. | survent4match_06!=.  

sort hhid_98 pn_98
egen first=rank(pn_98), by(hhid_98)  

keep if first==1


keep Findid hhid_98 hhentexit*_06 hhententer*_06 hh_panel* ///
sent*ecac1d ///
formal_* partner_* sloc_* starty_* kap_* ///
empout_* nhhemp_* noutemp_*  ntotemp_* ///
sex agegrp3 ///
educlvl3 fteduc2 ftempst ///
region qwealth ///
survent*match_06 


reshape long hhentexit@_06 hhententer@_06 ///
sent@ecac1d ///
formal_@ partner_@ sloc_@ starty_@ kap_@ ///
empout_@ nhhemp_@ noutemp_@ ntotemp_@ survent@match_06, i(Findid) j(ent_num) 

gen round=2006

keep if surventmatch_06!=.

merge m:1 Findid round using "HH ent Ind HH data.dta"

drop if _merge!=3


gen subseqemp=.
foreach num of numlist 1/4 {
replace subseqemp=ntotemp_`num' if surventmatch_06==`num'
}

*Same, increase, decrease

gen empdyn=.
*Same
replace empdyn=2 if subseqemp==ntotemp_ & subseqemp!=. & ntotemp_!=.
*More
replace empdyn=3 if subseqemp>ntotemp_ & subseqemp!=. & ntotemp_!=.
*Fewer
replace empdyn=1 if subseqemp<ntotemp_ & subseqemp!=. & ntotemp_!=.

*Table (partial)
tabu empdyn [aw=hh_panel_wt_98_06]

table empdyn [pw=hh_panel_wt_98_06], c(sum ntotemp_ sum subseqemp mean ntotemp_ mean subseqemp)

*Growth between 1998 and 2006
oprobit empdyn b1.sex b2.agegrp3 ///
b1.educlvl3 b1.fteduc2 b1.ftempst2 ///
b1.region b1.qwealth ///
b0.formal_ b0.partner_ ///
b1.sloc_ b5.starty_ ///
b1.kap_ b0.empout_ ///
b1.sentecac1d ///
[pw=hh_panel_wt_98_06]

estimates store entdyn06

margins, dydx(*) predict(outcome(1)) post

estimates store m1entdyn06


estimates restore entdyn06

margins, dydx(*) predict(outcome(2)) post

estimates store m2entdyn06


estimates restore entdyn06

margins, dydx(*) predict(outcome(3)) post

estimates store m3entdyn06

*Floor effect
*Growth between 1998 and 2006
oprobit empdyn b1.sex b2.agegrp3 ///
b1.educlvl3 b1.fteduc2 b1.ftempst2 ///
b1.region b1.qwealth ///
b0.formal_ b0.partner_ ///
b1.sloc_ b5.starty_ ///
b1.kap_ b0.empout_ ///
b1.sentecac1d ///
[pw=hh_panel_wt_98_06] if ntotemp_>1

*******Enterprise shaped--2006

use "HH Ent Ent wide.dta", clear

gen round=2006

merge 1:1 Findid round using "HH ent Ind HH data.dta"

drop if _merge!=3

***Keeping the folks who stayed and stayed in enterprises

keep if in_2006==1 & in_2012==1 

keep if survent1match_12!=. | survent2match_12!=. | survent3match_12!=. | survent4match_12!=.  

sort hhid_06 pn_06
egen first=rank(pn_06), by(hhid_06)  

keep if first==1


keep Findid hhid_06 hhentexit*_12 hhententer*_12 hh_panel* ///
sent*ecac1d ///
formal_* partner_* sloc_* starty_* kap_* ///
empout_* nhhemp_* noutemp_*  ntotemp_* ///
sex agegrp3 ///
educlvl3 fteduc2 ftempst ///
region qwealth ///
survent*match_12 


reshape long hhentexit@_12 hhententer@_12 ///
sent@ecac1d ///
formal_@ partner_@ sloc_@ starty_@ kap_@ ///
empout_@ nhhemp_@ noutemp_@ ntotemp_@ survent@match_12, i(Findid) j(ent_num) 

gen round=2012

keep if surventmatch_12!=.

merge m:1 Findid round using "HH ent Ind HH data.dta"

drop if _merge!=3


gen subseqemp=.
foreach num of numlist 1/4 {
replace subseqemp=ntotemp_`num' if surventmatch_12==`num'
}

*Same, increase, decrease

gen empdyn=.
*Same
replace empdyn=2 if subseqemp==ntotemp_ & subseqemp!=. & ntotemp_!=.
*More
replace empdyn=3 if subseqemp>ntotemp_ & subseqemp!=. & ntotemp_!=.
*Fewer
replace empdyn=1 if subseqemp<ntotemp_ & subseqemp!=. & ntotemp_!=.

*Table (partial)
tabu empdyn [aw=hh_panel_wt_06_12]

table empdyn [pw=hh_panel_wt_06_12], c(sum ntotemp_ sum subseqemp mean ntotemp_ mean subseqemp)

*Growth between 2006 and 2012
oprobit empdyn b1.sex b2.agegrp3 ///
b1.educlvl3 b1.fteduc2 b1.ftempst2 ///
b1.region b1.qwealth ///
b0.formal_ b0.partner_ ///
b1.sloc_ b5.starty_ ///
b1.kap_ b0.empout_ ///
b1.sentecac1d ///
[pw=hh_panel_wt_06_12]

estimates store entdyn12

margins, dydx(*) predict(outcome(1)) post

estimates store m1entdyn12


estimates restore entdyn12

margins, dydx(*) predict(outcome(2)) post

estimates store m2entdyn12


estimates restore entdyn12

margins, dydx(*) predict(outcome(3)) post

estimates store m3entdyn12

*Floor effect

*Growth between 2006 and 2012
oprobit empdyn b1.sex b2.agegrp3 ///
b1.educlvl3 b1.fteduc2 b1.ftempst2 ///
b1.region b1.qwealth ///
b0.formal_ b0.partner_ ///
b1.sloc_ b5.starty_ ///
b1.kap_ b0.empout_ ///
b1.sentecac1d ///
[pw=hh_panel_wt_06_12] if ntotemp_>1


*******Enterprise shaped--2012

use "HH Ent Ent wide.dta", clear

gen round=2012

merge 1:1 Findid round using "HH ent Ind HH data.dta"

drop if _merge!=3

***Keeping the folks who stayed and stayed in enterprises

keep if in_2012==1 & in_2018==1 

keep if survent1match_18!=. | survent2match_18!=. | survent3match_18!=. | survent4match_18!=.  

sort hhid_12 pn_12
egen first=rank(pn_12), by(hhid_12)  

keep if first==1


keep Findid hhid_12 hhentexit*_18 hhententer*_18 hh_panel* ///
sent*ecac1d ///
formal_* partner_* sloc_* starty_* kap_* ///
empout_* nhhemp_* noutemp_*  ntotemp_* ///
sex agegrp3 ///
educlvl3 fteduc2 ftempst ///
region qwealth ///
survent*match_18 


reshape long hhentexit@_18 hhententer@_18 ///
sent@ecac1d ///
formal_@ partner_@ sloc_@ starty_@ kap_@ ///
empout_@ nhhemp_@ noutemp_@ ntotemp_@ survent@match_18, i(Findid) j(ent_num) 

gen round=2018

keep if surventmatch_18!=.

merge m:1 Findid round using "HH ent Ind HH data.dta"

drop if _merge!=3


gen subseqemp=.
foreach num of numlist 1/4 {
replace subseqemp=ntotemp_`num' if surventmatch_18==`num'
}

*Same, increase, decrease

gen empdyn=.
*Same
replace empdyn=2 if subseqemp==ntotemp_ & subseqemp!=. & ntotemp_!=.
*More
replace empdyn=3 if subseqemp>ntotemp_ & subseqemp!=. & ntotemp_!=.
*Fewer
replace empdyn=1 if subseqemp<ntotemp_ & subseqemp!=. & ntotemp_!=.

*Table (partial)
tabu empdyn [aw=hh_panel_wt_12_18]

table empdyn [pw=hh_panel_wt_12_18], c(sum ntotemp_ sum subseqemp mean ntotemp_ mean subseqemp)

*Growth between 2012 and 2018
oprobit empdyn b1.sex b2.agegrp3 ///
b1.educlvl3 b1.fteduc2 b1.ftempst2 ///
b1.region b1.qwealth ///
b0.formal_ b0.partner_ ///
b1.sloc_ b5.starty_ ///
b1.kap_ b0.empout_ ///
b1.sentecac1d ///
[pw=hh_panel_wt_12_18]

estimates store entdyn18

margins, dydx(*) predict(outcome(1)) post

estimates store m1entdyn18


estimates restore entdyn18

margins, dydx(*) predict(outcome(2)) post

estimates store m2entdyn18


estimates restore entdyn18

margins, dydx(*) predict(outcome(3)) post

estimates store m3entdyn18


*Floor effect
oprobit empdyn b1.sex b2.agegrp3 ///
b1.educlvl3 b1.fteduc2 b1.ftempst2 ///
b1.region b1.qwealth ///
b0.formal_ b0.partner_ ///
b1.sloc_ b5.starty_ ///
b1.kap_ b0.empout_ ///
b1.sentecac1d ///
[pw=hh_panel_wt_12_18] if ntotemp_>1

esttab m1entdyn06 m2entdyn06 m3entdyn06 m1entdyn12 m2entdyn12 m3entdyn12 m1entdyn18 m2entdyn18 m3entdyn18 using Dyn_Ent_HHEnt.csv, starlevel(* 0.05 ** 0.01 *** 0.001) cells(b(star fmt(%9.3f)) se(par)) ///     
	 stats(N, fmt(%9.0g) label( "N (Obs.)" ))  ///
	mlabels( 	"1998-2006 Shrank" "1998-2006 Same size" "1998-2006 Grew" ///
	"2006-2012 Shrank" "2006-2012 Same size" "2006-2012 Grew" "2012-2018 Shrank" "2012-2018 Same size" "2012-2018 Grew") ///
	coeflabel( 2.sex "Female" 1.agegrp3 "<30" 3.agegrp3 "50+" ///
	3.educlvl3 "Less than Int." 4.educlvl3 "Intermediate" ///
	6.educlvl3 "Univ. and above" ///
	2.fteduc2 "Less than Int." 3.fteduc2 "Intermediate" 4.fteduc2 "University & above" ///
	2.ftempst2 "Private wage" 3.ftempst2 "Non-wage" ///
	 2.region "Alex. and Suez Canal" 3.region "Urban Lower" 4.region "Urban Upper" ///
	  5.region "Rural Lower" 6.region "Rural Upper" ///
	 2.qwealth "Poorer" 3.qwealth "Middle" 4.qwealth "Richer" 5.qwealth "Richest" ///
	 1.formal_ "Yes" 1.partner_ "Yes" ///
	 2.sloc_ "Shop" 3.sloc_ "Office/flat/building/rooms" ///
	4.sloc_ "Workshop/factory" 5.sloc_ "Mobile worker" 6.sloc_ "Street and similar vendors" ///
	7.sloc_ "Transport based" ///
	0.starty_ "Don't know" 1.starty_ "Before 1952" 2.starty_ "1952-1959" 3.starty_ "1960-1969" ///
	4.starty_ "1970-1979"  6.starty_ "1990-1999" ///
	 7.starty_ "2000-2009" 8.starty_ "2010-2018" ///
	 2.kap_ "<LE500" 3.kap_ "LE500-999" 4.kap_ "LE1000-4999" 5.kap_ "LE5000-9999" 6.kap_ "LE 10000+" 7.kap_ "D.K." ///
	 2.sentecac1d "Construction" 3.sentecac1d "Wholesale and retail" ///
	4.sentecac1d "Transportation and storage" 5.sentecac1d "Accommodation and food service" ///
	6.sentecac1d "Various professional acts." 7.sentecac1d "Other service" 1.empout_ "Yes" ///
	) ///
	refcat(2.sex "Sex (male omit.)" 1.agegrp3 "Age group (30-49 omit.)" ///
	3.educlvl3 "Education (illit. omit.)" 2.fteduc2 "Father's educ. (illit. omit)" ///
	2.ftempst2 "Father's work status (public wage omit.)" 2.region "Region (Greater Cairo omit.)" ///
	2.qwealth "Wealth quintile (Poorest omit.)" 1.formal_ "Ent. formal"  ///
	1.partner_ "Owned in partnership" ///
	2.sloc_ "Location (own home omit.)" 0.starty_ "Start year (1980-1989 omit.)" ///
	 2.kap_ "Capital of enterprise (none omit.)" 1.empout_ "Use outside emp." ///
	 2.sentecac1d "Economic activity (manuf. omit)"  ///
	) ///
	order (*sex *agegrp3 *educlvl3 *fteduc2 *ftempst2 *region *qwealth *formal_ *partner_ *sloc_ *starty_ *kap_ *empout_ *sentecac1d ///
	) ///
	nobase ///
	varwidth(12) modelwidth(8) replace

log close
